
static PyObject *pycv_2DRotationMatrix(PyObject *self, PyObject *args)
{
  CvPoint2D32f center;
  PyObject *pyobj_center = NULL;
  double angle;
  double scale;
  CvMat* map_matrix;
  PyObject *pyobj_map_matrix = NULL;

  if (!PyArg_ParseTuple(args, "OddO", &pyobj_center, &angle, &scale, &pyobj_map_matrix))
    return NULL;
  if (!convert_to_CvPoint2D32f(pyobj_center, &center, "center")) return NULL;
  if (!convert_to_CvMat(pyobj_map_matrix, &map_matrix, "map_matrix")) return NULL;
  ERRWRAP(cv2DRotationMatrix(center, angle, scale, map_matrix));
  Py_RETURN_NONE;
}

static PyObject *pycvAbs(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_src, &pyobj_dst))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvAbs(src, dst));
  Py_RETURN_NONE;
}

static PyObject *pycvAbsDiff(PyObject *self, PyObject *args)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvArr* src2;
  PyObject *pyobj_src2 = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_src1, &pyobj_src2, &pyobj_dst))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvArr(pyobj_src2, &src2, "src2")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvAbsDiff(src1, src2, dst));
  Py_RETURN_NONE;
}

static PyObject *pycvAbsDiffS(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvScalar value;
  PyObject *pyobj_value = NULL;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_src, &pyobj_dst, &pyobj_value))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if (!convert_to_CvScalar(pyobj_value, &value, "value")) return NULL;
  ERRWRAP(cvAbsDiffS(src, dst, value));
  Py_RETURN_NONE;
}

static PyObject *pycvAcc(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* image;
  PyObject *pyobj_image = NULL;
  CvArr* sum;
  PyObject *pyobj_sum = NULL;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "image", "sum", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|O", (char**)keywords, &pyobj_image, &pyobj_sum, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvArr(pyobj_sum, &sum, "sum")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvAcc(image, sum, mask));
  Py_RETURN_NONE;
}

static PyObject *pycvAdaptiveThreshold(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  double max_value;
  int adaptive_method = CV_ADAPTIVE_THRESH_MEAN_C;
  int threshold_type = CV_THRESH_BINARY;
  int block_size = 3;
  double param1 = 5;

  const char *keywords[] = { "src", "dst", "max_value", "adaptive_method", "threshold_type", "block_size", "param1", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOd|iiid", (char**)keywords, &pyobj_src, &pyobj_dst, &max_value, &adaptive_method, &threshold_type, &block_size, &param1))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvAdaptiveThreshold(src, dst, max_value, adaptive_method, threshold_type, block_size, param1));
  Py_RETURN_NONE;
}

static PyObject *pycvAdd(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvArr* src2;
  PyObject *pyobj_src2 = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "src1", "src2", "dst", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|O", (char**)keywords, &pyobj_src1, &pyobj_src2, &pyobj_dst, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvArr(pyobj_src2, &src2, "src2")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvAdd(src1, src2, dst, mask));
  Py_RETURN_NONE;
}

static PyObject *pycvAddS(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvScalar value;
  PyObject *pyobj_value = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "src1", "value", "dst", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|O", (char**)keywords, &pyobj_src1, &pyobj_value, &pyobj_dst, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvScalar(pyobj_value, &value, "value")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvAddS(src1, value, dst, mask));
  Py_RETURN_NONE;
}

static PyObject *pycvAddWeighted(PyObject *self, PyObject *args)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  double alpha;
  CvArr* src2;
  PyObject *pyobj_src2 = NULL;
  double beta;
  double gamma;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;

  if (!PyArg_ParseTuple(args, "OdOddO", &pyobj_src1, &alpha, &pyobj_src2, &beta, &gamma, &pyobj_dst))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvArr(pyobj_src2, &src2, "src2")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvAddWeighted(src1, alpha, src2, beta, gamma, dst));
  Py_RETURN_NONE;
}

static PyObject *pycvAnd(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvArr* src2;
  PyObject *pyobj_src2 = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "src1", "src2", "dst", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|O", (char**)keywords, &pyobj_src1, &pyobj_src2, &pyobj_dst, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvArr(pyobj_src2, &src2, "src2")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvAnd(src1, src2, dst, mask));
  Py_RETURN_NONE;
}

static PyObject *pycvAndS(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvScalar value;
  PyObject *pyobj_value = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "src1", "value", "dst", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|O", (char**)keywords, &pyobj_src1, &pyobj_value, &pyobj_dst, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvScalar(pyobj_value, &value, "value")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvAndS(src1, value, dst, mask));
  Py_RETURN_NONE;
}

static PyObject *pycvApproxChains(PyObject *self, PyObject *args, PyObject *kw)
{
  CvSeq* src_seq;
  PyObject *pyobj_src_seq = NULL;
  CvMemStorage* storage;
  PyObject *pyobj_storage = NULL;
  int method = CV_CHAIN_APPROX_SIMPLE;
  double parameter = 0;
  int minimal_perimeter = 0;
  int recursive = 0;

  const char *keywords[] = { "src_seq", "storage", "method", "parameter", "minimal_perimeter", "recursive", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|idii", (char**)keywords, &pyobj_src_seq, &pyobj_storage, &method, &parameter, &minimal_perimeter, &recursive))
    return NULL;
  if (!convert_to_CvSeq(pyobj_src_seq, &src_seq, "src_seq")) return NULL;
  if (!convert_to_CvMemStorage(pyobj_storage, &storage, "storage")) return NULL;
  CvSeq* r;
  ERRWRAP(r = cvApproxChains(src_seq, storage, method, parameter, minimal_perimeter, recursive));
  return FROM_CvSeqPTR(r);
}

static PyObject *pycvArcLength(PyObject *self, PyObject *args, PyObject *kw)
{
  cvarrseq curve;
  PyObject *pyobj_curve = NULL;
  CvSlice slice = CV_WHOLE_SEQ;
  PyObject *pyobj_slice = NULL;
  int is_closed = -1;

  const char *keywords[] = { "curve", "slice", "is_closed", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "O|Oi", (char**)keywords, &pyobj_curve, &pyobj_slice, &is_closed))
    return NULL;
  if (!convert_to_cvarrseq(pyobj_curve, &curve, "curve")) return NULL;
  if ((pyobj_slice != NULL) && !convert_to_CvSlice(pyobj_slice, &slice, "slice")) return NULL;
  double r;
  ERRWRAP(r = cvArcLength(curve.v, slice, is_closed));
  return FROM_double(r);
}

static PyObject *pycvAvg(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "arr", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "O|O", (char**)keywords, &pyobj_arr, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  CvScalar r;
  ERRWRAP(r = cvAvg(arr, mask));
  return FROM_CvScalar(r);
}

static PyObject *pycvAvgSdv(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  CvScalar mean;
  CvScalar std_dev;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "arr", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "O|O", (char**)keywords, &pyobj_arr, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvAvgSdv(arr, &mean, &std_dev, mask));
  return Py_BuildValue("NN", FROM_CvScalar(mean), FROM_CvScalar(std_dev));
}

static PyObject *pycvBackProjectPCA(PyObject *self, PyObject *args)
{
  CvArr* proj;
  PyObject *pyobj_proj = NULL;
  CvArr* avg;
  PyObject *pyobj_avg = NULL;
  CvArr* eigenvects;
  PyObject *pyobj_eigenvects = NULL;
  CvArr* result;
  PyObject *pyobj_result = NULL;

  if (!PyArg_ParseTuple(args, "OOOO", &pyobj_proj, &pyobj_avg, &pyobj_eigenvects, &pyobj_result))
    return NULL;
  if (!convert_to_CvArr(pyobj_proj, &proj, "proj")) return NULL;
  if (!convert_to_CvArr(pyobj_avg, &avg, "avg")) return NULL;
  if (!convert_to_CvArr(pyobj_eigenvects, &eigenvects, "eigenvects")) return NULL;
  if (!convert_to_CvArr(pyobj_result, &result, "result")) return NULL;
  ERRWRAP(cvBackProjectPCA(proj, avg, eigenvects, result));
  Py_RETURN_NONE;
}

static PyObject *pycvBoundingRect(PyObject *self, PyObject *args, PyObject *kw)
{
  cvarrseq points;
  PyObject *pyobj_points = NULL;
  int update = 0;

  const char *keywords[] = { "points", "update", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "O|i", (char**)keywords, &pyobj_points, &update))
    return NULL;
  if (!convert_to_cvarrseq(pyobj_points, &points, "points")) return NULL;
  CvRect r;
  ERRWRAP(r = cvBoundingRect(points.v, update));
  return FROM_CvRect(r);
}

static PyObject *pycvBoxPoints(PyObject *self, PyObject *args)
{
  CvBox2D box;
  PyObject *pyobj_box = NULL;
  CvPoint2D32f_4 pt;

  if (!PyArg_ParseTuple(args, "O", &pyobj_box))
    return NULL;
  if (!convert_to_CvBox2D(pyobj_box, &box, "box")) return NULL;
  ERRWRAP(cvBoxPoints(box, pt));
  return FROM_CvPoint2D32f_4(pt);
}

static PyObject *pycv_CV_CMP(PyObject *self, PyObject *args)
{
  int a;
  int b;

  if (!PyArg_ParseTuple(args, "ii", &a, &b))
    return NULL;
  int r;
  ERRWRAP(r = CV_CMP(a, b));
  return FROM_int(r);
}

static PyObject *pycv_CV_FOURCC(PyObject *self, PyObject *args)
{
  char c1;
  PyObject *pyobj_c1 = NULL;
  char c2;
  PyObject *pyobj_c2 = NULL;
  char c3;
  PyObject *pyobj_c3 = NULL;
  char c4;
  PyObject *pyobj_c4 = NULL;

  if (!PyArg_ParseTuple(args, "OOOO", &pyobj_c1, &pyobj_c2, &pyobj_c3, &pyobj_c4))
    return NULL;
  if (!convert_to_char(pyobj_c1, &c1, "c1")) return NULL;
  if (!convert_to_char(pyobj_c2, &c2, "c2")) return NULL;
  if (!convert_to_char(pyobj_c3, &c3, "c3")) return NULL;
  if (!convert_to_char(pyobj_c4, &c4, "c4")) return NULL;
  int r;
  ERRWRAP(r = CV_FOURCC(c1, c2, c3, c4));
  return FROM_int(r);
}

static PyObject *pycv_CV_IABS(PyObject *self, PyObject *args)
{
  int a;

  if (!PyArg_ParseTuple(args, "i", &a))
    return NULL;
  int r;
  ERRWRAP(r = CV_IABS(a));
  return FROM_int(r);
}

static PyObject *pycv_CV_IS_SEQ_CLOSED(PyObject *self, PyObject *args)
{
  CvSeq* s;
  PyObject *pyobj_s = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_s))
    return NULL;
  if (!convert_to_CvSeq(pyobj_s, &s, "s")) return NULL;
  int r;
  ERRWRAP(r = CV_IS_SEQ_CLOSED(s));
  return FROM_int(r);
}

static PyObject *pycv_CV_IS_SEQ_CONVEX(PyObject *self, PyObject *args)
{
  CvSeq* s;
  PyObject *pyobj_s = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_s))
    return NULL;
  if (!convert_to_CvSeq(pyobj_s, &s, "s")) return NULL;
  int r;
  ERRWRAP(r = CV_IS_SEQ_CONVEX(s));
  return FROM_int(r);
}

static PyObject *pycv_CV_IS_SEQ_CURVE(PyObject *self, PyObject *args)
{
  CvSeq* s;
  PyObject *pyobj_s = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_s))
    return NULL;
  if (!convert_to_CvSeq(pyobj_s, &s, "s")) return NULL;
  int r;
  ERRWRAP(r = CV_IS_SEQ_CURVE(s));
  return FROM_int(r);
}

static PyObject *pycv_CV_IS_SEQ_HOLE(PyObject *self, PyObject *args)
{
  CvSeq* s;
  PyObject *pyobj_s = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_s))
    return NULL;
  if (!convert_to_CvSeq(pyobj_s, &s, "s")) return NULL;
  int r;
  ERRWRAP(r = CV_IS_SEQ_HOLE(s));
  return FROM_int(r);
}

static PyObject *pycv_CV_IS_SEQ_INDEX(PyObject *self, PyObject *args)
{
  CvSeq* s;
  PyObject *pyobj_s = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_s))
    return NULL;
  if (!convert_to_CvSeq(pyobj_s, &s, "s")) return NULL;
  int r;
  ERRWRAP(r = CV_IS_SEQ_INDEX(s));
  return FROM_int(r);
}

static PyObject *pycv_CV_IS_SEQ_SIMPLE(PyObject *self, PyObject *args)
{
  CvSeq* s;
  PyObject *pyobj_s = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_s))
    return NULL;
  if (!convert_to_CvSeq(pyobj_s, &s, "s")) return NULL;
  int r;
  ERRWRAP(r = CV_IS_SEQ_SIMPLE(s));
  return FROM_int(r);
}

static PyObject *pycv_CV_MAKETYPE(PyObject *self, PyObject *args)
{
  int depth;
  int cn;

  if (!PyArg_ParseTuple(args, "ii", &depth, &cn))
    return NULL;
  int r;
  ERRWRAP(r = CV_MAKETYPE(depth, cn));
  return FROM_int(r);
}

static PyObject *pycv_CV_MAT_CN(PyObject *self, PyObject *args)
{
  int i;

  if (!PyArg_ParseTuple(args, "i", &i))
    return NULL;
  int r;
  ERRWRAP(r = CV_MAT_CN(i));
  return FROM_int(r);
}

static PyObject *pycv_CV_MAT_DEPTH(PyObject *self, PyObject *args)
{
  int i;

  if (!PyArg_ParseTuple(args, "i", &i))
    return NULL;
  int r;
  ERRWRAP(r = CV_MAT_DEPTH(i));
  return FROM_int(r);
}

static PyObject *pycv_CV_RGB(PyObject *self, PyObject *args)
{
  double red;
  double grn;
  double blu;

  if (!PyArg_ParseTuple(args, "ddd", &red, &grn, &blu))
    return NULL;
  CvScalar r;
  ERRWRAP(r = CV_RGB(red, grn, blu));
  return FROM_CvScalar(r);
}

static PyObject *pycv_CV_SIGN(PyObject *self, PyObject *args)
{
  int a;

  if (!PyArg_ParseTuple(args, "i", &a))
    return NULL;
  int r;
  ERRWRAP(r = CV_SIGN(a));
  return FROM_int(r);
}

static PyObject *pycvCalcArrBackProject(PyObject *self, PyObject *args)
{
  CvArrs image;
  PyObject *pyobj_image = NULL;
  CvArr* back_project;
  PyObject *pyobj_back_project = NULL;
  CvHistogram* hist;
  PyObject *pyobj_hist = NULL;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_image, &pyobj_back_project, &pyobj_hist))
    return NULL;
  if (!convert_to_CvArrs(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvArr(pyobj_back_project, &back_project, "back_project")) return NULL;
  if (!convert_to_CvHistogram(pyobj_hist, &hist, "hist")) return NULL;
  ERRWRAP(cvCalcArrBackProject(image.ims, back_project, hist));
  Py_RETURN_NONE;
}

static PyObject *pycvCalcArrHist(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArrs image;
  PyObject *pyobj_image = NULL;
  CvHistogram* hist;
  PyObject *pyobj_hist = NULL;
  int accumulate = 0;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "image", "hist", "accumulate", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|iO", (char**)keywords, &pyobj_image, &pyobj_hist, &accumulate, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArrs(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvHistogram(pyobj_hist, &hist, "hist")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvCalcArrHist(image.ims, hist, accumulate, mask));
  Py_RETURN_NONE;
}

static PyObject *pycvCalcBackProject(PyObject *self, PyObject *args)
{
  IplImages image;
  PyObject *pyobj_image = NULL;
  CvArr* back_project;
  PyObject *pyobj_back_project = NULL;
  CvHistogram* hist;
  PyObject *pyobj_hist = NULL;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_image, &pyobj_back_project, &pyobj_hist))
    return NULL;
  if (!convert_to_IplImages(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvArr(pyobj_back_project, &back_project, "back_project")) return NULL;
  if (!convert_to_CvHistogram(pyobj_hist, &hist, "hist")) return NULL;
  ERRWRAP(cvCalcBackProject(image.ims, back_project, hist));
  Py_RETURN_NONE;
}

static PyObject *pycvCalcBackProjectPatch(PyObject *self, PyObject *args)
{
  IplImages images;
  PyObject *pyobj_images = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvSize patch_size;
  PyObject *pyobj_patch_size = NULL;
  CvHistogram* hist;
  PyObject *pyobj_hist = NULL;
  int method;
  float factor;

  if (!PyArg_ParseTuple(args, "OOOOif", &pyobj_images, &pyobj_dst, &pyobj_patch_size, &pyobj_hist, &method, &factor))
    return NULL;
  if (!convert_to_IplImages(pyobj_images, &images, "images")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if (!convert_to_CvSize(pyobj_patch_size, &patch_size, "patch_size")) return NULL;
  if (!convert_to_CvHistogram(pyobj_hist, &hist, "hist")) return NULL;
  ERRWRAP(cvCalcBackProjectPatch(images.ims, dst, patch_size, hist, method, factor));
  Py_RETURN_NONE;
}

static PyObject *pycvCalcCovarMatrix(PyObject *self, PyObject *args)
{
  cvarr_count vects;
  PyObject *pyobj_vects = NULL;
  CvArr* cov_mat;
  PyObject *pyobj_cov_mat = NULL;
  CvArr* avg;
  PyObject *pyobj_avg = NULL;
  int flags;

  if (!PyArg_ParseTuple(args, "OOOi", &pyobj_vects, &pyobj_cov_mat, &pyobj_avg, &flags))
    return NULL;
  if (!convert_to_cvarr_count(pyobj_vects, &vects, "vects")) return NULL;
  if (!convert_to_CvArr(pyobj_cov_mat, &cov_mat, "cov_mat")) return NULL;
  if (!convert_to_CvArr(pyobj_avg, &avg, "avg")) return NULL;
  ERRWRAP(cvCalcCovarMatrix((const CvArr **)vects.cvarr,vects.count, cov_mat, avg, flags));
  Py_RETURN_NONE;
}

static PyObject *pycvCalcGlobalOrientation(PyObject *self, PyObject *args)
{
  CvArr* orientation;
  PyObject *pyobj_orientation = NULL;
  CvArr* mask;
  PyObject *pyobj_mask = NULL;
  CvArr* mhi;
  PyObject *pyobj_mhi = NULL;
  double timestamp;
  double duration;

  if (!PyArg_ParseTuple(args, "OOOdd", &pyobj_orientation, &pyobj_mask, &pyobj_mhi, &timestamp, &duration))
    return NULL;
  if (!convert_to_CvArr(pyobj_orientation, &orientation, "orientation")) return NULL;
  if (!convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  if (!convert_to_CvArr(pyobj_mhi, &mhi, "mhi")) return NULL;
  ERRWRAP(cvCalcGlobalOrientation(orientation, mask, mhi, timestamp, duration));
  Py_RETURN_NONE;
}

static PyObject *pycvCalcHist(PyObject *self, PyObject *args, PyObject *kw)
{
  IplImages image;
  PyObject *pyobj_image = NULL;
  CvHistogram* hist;
  PyObject *pyobj_hist = NULL;
  int accumulate = 0;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "image", "hist", "accumulate", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|iO", (char**)keywords, &pyobj_image, &pyobj_hist, &accumulate, &pyobj_mask))
    return NULL;
  if (!convert_to_IplImages(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvHistogram(pyobj_hist, &hist, "hist")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvCalcHist(image.ims, hist, accumulate, mask));
  Py_RETURN_NONE;
}

static PyObject *pycvCalcImageHomography(PyObject *self, PyObject *args)
{
  floats line;
  PyObject *pyobj_line = NULL;
  CvPoint3D32f* points;
  PyObject *pyobj_points = NULL;
  CvMatr32f_i intrinsic;
  CvMatr32f_i homography;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_line, &pyobj_points))
    return NULL;
  if (!convert_to_floats(pyobj_line, &line, "line")) return NULL;
  if (!convert_to_CvPoint3D32fPTR(pyobj_points, &points, "points")) return NULL;
  ERRWRAP(cvCalcImageHomography(line.f, points, intrinsic, homography));
  return Py_BuildValue("NN", FROM_CvMatr32f_i(intrinsic), FROM_CvMatr32f_i(homography));
}

static PyObject *pycvCalcMotionGradient(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* mhi;
  PyObject *pyobj_mhi = NULL;
  CvArr* mask;
  PyObject *pyobj_mask = NULL;
  CvArr* orientation;
  PyObject *pyobj_orientation = NULL;
  double delta1;
  double delta2;
  int aperture_size = 3;

  const char *keywords[] = { "mhi", "mask", "orientation", "delta1", "delta2", "aperture_size", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOOdd|i", (char**)keywords, &pyobj_mhi, &pyobj_mask, &pyobj_orientation, &delta1, &delta2, &aperture_size))
    return NULL;
  if (!convert_to_CvArr(pyobj_mhi, &mhi, "mhi")) return NULL;
  if (!convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  if (!convert_to_CvArr(pyobj_orientation, &orientation, "orientation")) return NULL;
  ERRWRAP(cvCalcMotionGradient(mhi, mask, orientation, delta1, delta2, aperture_size));
  Py_RETURN_NONE;
}

static PyObject *pycvCalcOpticalFlowBM(PyObject *self, PyObject *args)
{
  CvArr* prev;
  PyObject *pyobj_prev = NULL;
  CvArr* curr;
  PyObject *pyobj_curr = NULL;
  CvSize block_size;
  PyObject *pyobj_block_size = NULL;
  CvSize shift_size;
  PyObject *pyobj_shift_size = NULL;
  CvSize max_range;
  PyObject *pyobj_max_range = NULL;
  int use_previous;
  CvArr* velx;
  PyObject *pyobj_velx = NULL;
  CvArr* vely;
  PyObject *pyobj_vely = NULL;

  if (!PyArg_ParseTuple(args, "OOOOOiOO", &pyobj_prev, &pyobj_curr, &pyobj_block_size, &pyobj_shift_size, &pyobj_max_range, &use_previous, &pyobj_velx, &pyobj_vely))
    return NULL;
  if (!convert_to_CvArr(pyobj_prev, &prev, "prev")) return NULL;
  if (!convert_to_CvArr(pyobj_curr, &curr, "curr")) return NULL;
  if (!convert_to_CvSize(pyobj_block_size, &block_size, "block_size")) return NULL;
  if (!convert_to_CvSize(pyobj_shift_size, &shift_size, "shift_size")) return NULL;
  if (!convert_to_CvSize(pyobj_max_range, &max_range, "max_range")) return NULL;
  if (!convert_to_CvArr(pyobj_velx, &velx, "velx")) return NULL;
  if (!convert_to_CvArr(pyobj_vely, &vely, "vely")) return NULL;
  ERRWRAP(cvCalcOpticalFlowBM(prev, curr, block_size, shift_size, max_range, use_previous, velx, vely));
  Py_RETURN_NONE;
}

static PyObject *pycvCalcOpticalFlowHS(PyObject *self, PyObject *args)
{
  CvArr* prev;
  PyObject *pyobj_prev = NULL;
  CvArr* curr;
  PyObject *pyobj_curr = NULL;
  int use_previous;
  CvArr* velx;
  PyObject *pyobj_velx = NULL;
  CvArr* vely;
  PyObject *pyobj_vely = NULL;
  double lambda;
  CvTermCriteria criteria;
  PyObject *pyobj_criteria = NULL;

  if (!PyArg_ParseTuple(args, "OOiOOdO", &pyobj_prev, &pyobj_curr, &use_previous, &pyobj_velx, &pyobj_vely, &lambda, &pyobj_criteria))
    return NULL;
  if (!convert_to_CvArr(pyobj_prev, &prev, "prev")) return NULL;
  if (!convert_to_CvArr(pyobj_curr, &curr, "curr")) return NULL;
  if (!convert_to_CvArr(pyobj_velx, &velx, "velx")) return NULL;
  if (!convert_to_CvArr(pyobj_vely, &vely, "vely")) return NULL;
  if (!convert_to_CvTermCriteria(pyobj_criteria, &criteria, "criteria")) return NULL;
  ERRWRAP(cvCalcOpticalFlowHS(prev, curr, use_previous, velx, vely, lambda, criteria));
  Py_RETURN_NONE;
}

static PyObject *pycvCalcOpticalFlowLK(PyObject *self, PyObject *args)
{
  CvArr* prev;
  PyObject *pyobj_prev = NULL;
  CvArr* curr;
  PyObject *pyobj_curr = NULL;
  CvSize win_size;
  PyObject *pyobj_win_size = NULL;
  CvArr* velx;
  PyObject *pyobj_velx = NULL;
  CvArr* vely;
  PyObject *pyobj_vely = NULL;

  if (!PyArg_ParseTuple(args, "OOOOO", &pyobj_prev, &pyobj_curr, &pyobj_win_size, &pyobj_velx, &pyobj_vely))
    return NULL;
  if (!convert_to_CvArr(pyobj_prev, &prev, "prev")) return NULL;
  if (!convert_to_CvArr(pyobj_curr, &curr, "curr")) return NULL;
  if (!convert_to_CvSize(pyobj_win_size, &win_size, "win_size")) return NULL;
  if (!convert_to_CvArr(pyobj_velx, &velx, "velx")) return NULL;
  if (!convert_to_CvArr(pyobj_vely, &vely, "vely")) return NULL;
  ERRWRAP(cvCalcOpticalFlowLK(prev, curr, win_size, velx, vely));
  Py_RETURN_NONE;
}

static PyObject *pycvCalcPCA(PyObject *self, PyObject *args)
{
  CvArr* data;
  PyObject *pyobj_data = NULL;
  CvArr* avg;
  PyObject *pyobj_avg = NULL;
  CvArr* eigenvalues;
  PyObject *pyobj_eigenvalues = NULL;
  CvArr* eigenvectors;
  PyObject *pyobj_eigenvectors = NULL;
  int flags;

  if (!PyArg_ParseTuple(args, "OOOOi", &pyobj_data, &pyobj_avg, &pyobj_eigenvalues, &pyobj_eigenvectors, &flags))
    return NULL;
  if (!convert_to_CvArr(pyobj_data, &data, "data")) return NULL;
  if (!convert_to_CvArr(pyobj_avg, &avg, "avg")) return NULL;
  if (!convert_to_CvArr(pyobj_eigenvalues, &eigenvalues, "eigenvalues")) return NULL;
  if (!convert_to_CvArr(pyobj_eigenvectors, &eigenvectors, "eigenvectors")) return NULL;
  ERRWRAP(cvCalcPCA(data, avg, eigenvalues, eigenvectors, flags));
  Py_RETURN_NONE;
}

static PyObject *pycvCalcPGH(PyObject *self, PyObject *args)
{
  CvSeq* contour;
  PyObject *pyobj_contour = NULL;
  CvHistogram* hist;
  PyObject *pyobj_hist = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_contour, &pyobj_hist))
    return NULL;
  if (!convert_to_CvSeq(pyobj_contour, &contour, "contour")) return NULL;
  if (!convert_to_CvHistogram(pyobj_hist, &hist, "hist")) return NULL;
  ERRWRAP(cvCalcPGH(contour, hist));
  Py_RETURN_NONE;
}

static PyObject *pycvCalcProbDensity(PyObject *self, PyObject *args, PyObject *kw)
{
  CvHistogram* hist1;
  PyObject *pyobj_hist1 = NULL;
  CvHistogram* hist2;
  PyObject *pyobj_hist2 = NULL;
  CvHistogram* dst_hist;
  PyObject *pyobj_dst_hist = NULL;
  double scale = 255;

  const char *keywords[] = { "hist1", "hist2", "dst_hist", "scale", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|d", (char**)keywords, &pyobj_hist1, &pyobj_hist2, &pyobj_dst_hist, &scale))
    return NULL;
  if (!convert_to_CvHistogram(pyobj_hist1, &hist1, "hist1")) return NULL;
  if (!convert_to_CvHistogram(pyobj_hist2, &hist2, "hist2")) return NULL;
  if (!convert_to_CvHistogram(pyobj_dst_hist, &dst_hist, "dst_hist")) return NULL;
  ERRWRAP(cvCalcProbDensity(hist1, hist2, dst_hist, scale));
  Py_RETURN_NONE;
}

static PyObject *pycvCalcSubdivVoronoi2D(PyObject *self, PyObject *args)
{
  CvSubdiv2D* subdiv;
  PyObject *pyobj_subdiv = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_subdiv))
    return NULL;
  if (!convert_to_CvSubdiv2DPTR(pyobj_subdiv, &subdiv, "subdiv")) return NULL;
  ERRWRAP(cvCalcSubdivVoronoi2D(subdiv));
  Py_RETURN_NONE;
}

static PyObject *pycvCalibrateCamera2(PyObject *self, PyObject *args, PyObject *kw)
{
  CvMat* object_points;
  PyObject *pyobj_object_points = NULL;
  CvMat* image_points;
  PyObject *pyobj_image_points = NULL;
  CvMat* point_counts;
  PyObject *pyobj_point_counts = NULL;
  CvSize image_size;
  PyObject *pyobj_image_size = NULL;
  CvMat* intrinsic_matrix;
  PyObject *pyobj_intrinsic_matrix = NULL;
  CvMat* distortion_coeffs;
  PyObject *pyobj_distortion_coeffs = NULL;
  CvMat* rotation_vectors;
  PyObject *pyobj_rotation_vectors = NULL;
  CvMat* translation_vectors;
  PyObject *pyobj_translation_vectors = NULL;
  int flags = 0;

  const char *keywords[] = { "object_points", "image_points", "point_counts", "image_size", "intrinsic_matrix", "distortion_coeffs", "rotation_vectors", "translation_vectors", "flags", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOOOOOOO|i", (char**)keywords, &pyobj_object_points, &pyobj_image_points, &pyobj_point_counts, &pyobj_image_size, &pyobj_intrinsic_matrix, &pyobj_distortion_coeffs, &pyobj_rotation_vectors, &pyobj_translation_vectors, &flags))
    return NULL;
  if (!convert_to_CvMat(pyobj_object_points, &object_points, "object_points")) return NULL;
  if (!convert_to_CvMat(pyobj_image_points, &image_points, "image_points")) return NULL;
  if (!convert_to_CvMat(pyobj_point_counts, &point_counts, "point_counts")) return NULL;
  if (!convert_to_CvSize(pyobj_image_size, &image_size, "image_size")) return NULL;
  if (!convert_to_CvMat(pyobj_intrinsic_matrix, &intrinsic_matrix, "intrinsic_matrix")) return NULL;
  if (!convert_to_CvMat(pyobj_distortion_coeffs, &distortion_coeffs, "distortion_coeffs")) return NULL;
  if (!convert_to_CvMat(pyobj_rotation_vectors, &rotation_vectors, "rotation_vectors")) return NULL;
  if (!convert_to_CvMat(pyobj_translation_vectors, &translation_vectors, "translation_vectors")) return NULL;
  ERRWRAP(cvCalibrateCamera2(object_points, image_points, point_counts, image_size, intrinsic_matrix, distortion_coeffs, rotation_vectors, translation_vectors, flags));
  Py_RETURN_NONE;
}

static PyObject *pycvCalibrationMatrixValues(PyObject *self, PyObject *args, PyObject *kw)
{
  CvMat* calibMatr;
  PyObject *pyobj_calibMatr = NULL;
  CvSize image_size;
  PyObject *pyobj_image_size = NULL;
  double apertureWidth = 0;
  double apertureHeight = 0;
  double fovx;
  double fovy;
  double focalLength;
  CvPoint2D64f principalPoint;
  double pixelAspectRatio;

  const char *keywords[] = { "calibMatr", "image_size", "apertureWidth", "apertureHeight", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|dd", (char**)keywords, &pyobj_calibMatr, &pyobj_image_size, &apertureWidth, &apertureHeight))
    return NULL;
  if (!convert_to_CvMat(pyobj_calibMatr, &calibMatr, "calibMatr")) return NULL;
  if (!convert_to_CvSize(pyobj_image_size, &image_size, "image_size")) return NULL;
  ERRWRAP(cvCalibrationMatrixValues(calibMatr, image_size, apertureWidth, apertureHeight, &fovx, &fovy, &focalLength, &principalPoint, &pixelAspectRatio));
  return Py_BuildValue("NNNNN", FROM_double(fovx), FROM_double(fovy), FROM_double(focalLength), FROM_CvPoint2D64f(principalPoint), FROM_double(pixelAspectRatio));
}

static PyObject *pycvCamShift(PyObject *self, PyObject *args)
{
  CvArr* prob_image;
  PyObject *pyobj_prob_image = NULL;
  CvRect window;
  PyObject *pyobj_window = NULL;
  CvTermCriteria criteria;
  PyObject *pyobj_criteria = NULL;
  CvConnectedComp comp;
  CvBox2D box;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_prob_image, &pyobj_window, &pyobj_criteria))
    return NULL;
  if (!convert_to_CvArr(pyobj_prob_image, &prob_image, "prob_image")) return NULL;
  if (!convert_to_CvRect(pyobj_window, &window, "window")) return NULL;
  if (!convert_to_CvTermCriteria(pyobj_criteria, &criteria, "criteria")) return NULL;
  int r;
  ERRWRAP(r = cvCamShift(prob_image, window, criteria, &comp, &box));
  return Py_BuildValue("NNN", FROM_int(r), FROM_CvConnectedComp(comp), FROM_CvBox2D(box));
}

static PyObject *pycvCanny(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* image;
  PyObject *pyobj_image = NULL;
  CvArr* edges;
  PyObject *pyobj_edges = NULL;
  double threshold1;
  double threshold2;
  int aperture_size = 3;

  const char *keywords[] = { "image", "edges", "threshold1", "threshold2", "aperture_size", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOdd|i", (char**)keywords, &pyobj_image, &pyobj_edges, &threshold1, &threshold2, &aperture_size))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvArr(pyobj_edges, &edges, "edges")) return NULL;
  ERRWRAP(cvCanny(image, edges, threshold1, threshold2, aperture_size));
  Py_RETURN_NONE;
}

static PyObject *pycvCaptureFromCAM(PyObject *self, PyObject *args)
{
  int index;

  if (!PyArg_ParseTuple(args, "i", &index))
    return NULL;
  CvCapture* r;
  ERRWRAP(r = cvCaptureFromCAM(index));
  return FROM_CvCapturePTR(r);
}

static PyObject *pycvCaptureFromFile(PyObject *self, PyObject *args)
{
  char* filename;

  if (!PyArg_ParseTuple(args, "s", &filename))
    return NULL;
  CvCapture* r;
  ERRWRAP(r = cvCaptureFromFile(filename));
  return FROM_CvCapturePTR(r);
}

static PyObject *pycvCartToPolar(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* x;
  PyObject *pyobj_x = NULL;
  CvArr* y;
  PyObject *pyobj_y = NULL;
  CvArr* magnitude;
  PyObject *pyobj_magnitude = NULL;
  CvArr* angle = NULL;
  PyObject *pyobj_angle = NULL;
  int angle_in_degrees;

  const char *keywords[] = { "x", "y", "magnitude", "angle", "angle_in_degrees", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOOi|O", (char**)keywords, &pyobj_x, &pyobj_y, &pyobj_magnitude, &pyobj_angle, &angle_in_degrees))
    return NULL;
  if (!convert_to_CvArr(pyobj_x, &x, "x")) return NULL;
  if (!convert_to_CvArr(pyobj_y, &y, "y")) return NULL;
  if (!convert_to_CvArr(pyobj_magnitude, &magnitude, "magnitude")) return NULL;
  if ((pyobj_angle != NULL) && !convert_to_CvArr(pyobj_angle, &angle, "angle")) return NULL;
  ERRWRAP(cvCartToPolar(x, y, magnitude, angle, angle_in_degrees));
  Py_RETURN_NONE;
}

static PyObject *pycvCbrt(PyObject *self, PyObject *args)
{
  float value;

  if (!PyArg_ParseTuple(args, "f", &value))
    return NULL;
  float r;
  ERRWRAP(r = cvCbrt(value));
  return FROM_float(r);
}

static PyObject *pycvCeil(PyObject *self, PyObject *args)
{
  double value;

  if (!PyArg_ParseTuple(args, "d", &value))
    return NULL;
  int r;
  ERRWRAP(r = cvCeil(value));
  return FROM_int(r);
}

static PyObject *pycvCheckArr(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  int flags = 0;
  double min_val = 0;
  double max_val = 0;

  const char *keywords[] = { "arr", "flags", "min_val", "max_val", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "O|idd", (char**)keywords, &pyobj_arr, &flags, &min_val, &max_val))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  int r;
  ERRWRAP(r = cvCheckArr(arr, flags, min_val, max_val));
  return FROM_int(r);
}

static PyObject *pycvCheckContourConvexity(PyObject *self, PyObject *args)
{
  cvarrseq contour;
  PyObject *pyobj_contour = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_contour))
    return NULL;
  if (!convert_to_cvarrseq(pyobj_contour, &contour, "contour")) return NULL;
  int r;
  ERRWRAP(r = cvCheckContourConvexity(contour.v));
  return FROM_int(r);
}

static PyObject *pycvCircle(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* img;
  PyObject *pyobj_img = NULL;
  CvPoint pt1;
  PyObject *pyobj_pt1 = NULL;
  int radius;
  CvScalar color;
  PyObject *pyobj_color = NULL;
  int thickness = 1;
  int line_type = 8;
  int shift = 0;

  const char *keywords[] = { "img", "pt1", "radius", "color", "thickness", "line_type", "shift", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOiO|iii", (char**)keywords, &pyobj_img, &pyobj_pt1, &radius, &pyobj_color, &thickness, &line_type, &shift))
    return NULL;
  if (!convert_to_CvArr(pyobj_img, &img, "img")) return NULL;
  if (!convert_to_CvPoint(pyobj_pt1, &pt1, "pt1")) return NULL;
  if (!convert_to_CvScalar(pyobj_color, &color, "color")) return NULL;
  ERRWRAP(cvCircle(img, pt1, radius, color, thickness, line_type, shift));
  Py_RETURN_NONE;
}

static PyObject *pycvClearHist(PyObject *self, PyObject *args)
{
  CvHistogram* hist;
  PyObject *pyobj_hist = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_hist))
    return NULL;
  if (!convert_to_CvHistogram(pyobj_hist, &hist, "hist")) return NULL;
  ERRWRAP(cvClearHist(hist));
  Py_RETURN_NONE;
}

static PyObject *pycvClearND(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  ints idx;
  PyObject *pyobj_idx = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_arr, &pyobj_idx))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  if (!convert_to_ints(pyobj_idx, &idx, "idx")) return NULL;
  ERRWRAP(cvClearND(arr, idx.i));
  Py_RETURN_NONE;
}

static PyObject *pycvClearSeq(PyObject *self, PyObject *args)
{
  CvSeq* seq;
  PyObject *pyobj_seq = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_seq))
    return NULL;
  if (!convert_to_CvSeq(pyobj_seq, &seq, "seq")) return NULL;
  ERRWRAP(cvClearSeq(seq));
  Py_RETURN_NONE;
}

static PyObject *pycvClearSubdivVoronoi2D(PyObject *self, PyObject *args)
{
  CvSubdiv2D* subdiv;
  PyObject *pyobj_subdiv = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_subdiv))
    return NULL;
  if (!convert_to_CvSubdiv2DPTR(pyobj_subdiv, &subdiv, "subdiv")) return NULL;
  ERRWRAP(cvClearSubdivVoronoi2D(subdiv));
  Py_RETURN_NONE;
}

static PyObject *pycvCloneImage(PyObject *self, PyObject *args)
{
  IplImage* image;
  PyObject *pyobj_image = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_image))
    return NULL;
  if (!convert_to_IplImage(pyobj_image, &image, "image")) return NULL;
  IplImage* r;
  ERRWRAP(r = cvCloneImage(image));
  return FROM_IplImagePTR(r);
}

static PyObject *pycvCloneMat(PyObject *self, PyObject *args)
{
  CvMat* mat;
  PyObject *pyobj_mat = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_mat))
    return NULL;
  if (!convert_to_CvMat(pyobj_mat, &mat, "mat")) return NULL;
  CvMat* r;
  ERRWRAP(r = cvCloneMat(mat));
  return FROM_CvMatPTR(r);
}

static PyObject *pycvCloneMatND(PyObject *self, PyObject *args)
{
  CvMatND* mat;
  PyObject *pyobj_mat = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_mat))
    return NULL;
  if (!convert_to_CvMatND(pyobj_mat, &mat, "mat")) return NULL;
  CvMatND* r;
  ERRWRAP(r = cvCloneMatND(mat));
  return FROM_CvMatNDPTR(r);
}

static PyObject *pycvCloneSeq(PyObject *self, PyObject *args)
{
  CvSeq* seq;
  PyObject *pyobj_seq = NULL;
  CvMemStorage* storage;
  PyObject *pyobj_storage = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_seq, &pyobj_storage))
    return NULL;
  if (!convert_to_CvSeq(pyobj_seq, &seq, "seq")) return NULL;
  if (!convert_to_CvMemStorage(pyobj_storage, &storage, "storage")) return NULL;
  ERRWRAP(cvCloneSeq(seq, storage));
  Py_RETURN_NONE;
}

static PyObject *pycvCmp(PyObject *self, PyObject *args)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvArr* src2;
  PyObject *pyobj_src2 = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  int cmp_op;

  if (!PyArg_ParseTuple(args, "OOOi", &pyobj_src1, &pyobj_src2, &pyobj_dst, &cmp_op))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvArr(pyobj_src2, &src2, "src2")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvCmp(src1, src2, dst, cmp_op));
  Py_RETURN_NONE;
}

static PyObject *pycvCmpS(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  double value;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  int cmp_op;

  if (!PyArg_ParseTuple(args, "OdOi", &pyobj_src, &value, &pyobj_dst, &cmp_op))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvCmpS(src, value, dst, cmp_op));
  Py_RETURN_NONE;
}

static PyObject *pycvCompareHist(PyObject *self, PyObject *args)
{
  CvHistogram* hist1;
  PyObject *pyobj_hist1 = NULL;
  CvHistogram* hist2;
  PyObject *pyobj_hist2 = NULL;
  int method;

  if (!PyArg_ParseTuple(args, "OOi", &pyobj_hist1, &pyobj_hist2, &method))
    return NULL;
  if (!convert_to_CvHistogram(pyobj_hist1, &hist1, "hist1")) return NULL;
  if (!convert_to_CvHistogram(pyobj_hist2, &hist2, "hist2")) return NULL;
  ERRWRAP(cvCompareHist(hist1, hist2, method));
  Py_RETURN_NONE;
}

static PyObject *pycvContourArea(PyObject *self, PyObject *args, PyObject *kw)
{
  cvarrseq contour;
  PyObject *pyobj_contour = NULL;
  CvSlice slice = CV_WHOLE_SEQ;
  PyObject *pyobj_slice = NULL;

  const char *keywords[] = { "contour", "slice", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "O|O", (char**)keywords, &pyobj_contour, &pyobj_slice))
    return NULL;
  if (!convert_to_cvarrseq(pyobj_contour, &contour, "contour")) return NULL;
  if ((pyobj_slice != NULL) && !convert_to_CvSlice(pyobj_slice, &slice, "slice")) return NULL;
  double r;
  ERRWRAP(r = cvContourArea(contour.v, slice));
  return FROM_double(r);
}

static PyObject *pycvContourFromContourTree(PyObject *self, PyObject *args)
{
  CvContourTree* tree;
  PyObject *pyobj_tree = NULL;
  CvMemStorage* storage;
  PyObject *pyobj_storage = NULL;
  CvTermCriteria criteria;
  PyObject *pyobj_criteria = NULL;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_tree, &pyobj_storage, &pyobj_criteria))
    return NULL;
  if (!convert_to_CvContourTreePTR(pyobj_tree, &tree, "tree")) return NULL;
  if (!convert_to_CvMemStorage(pyobj_storage, &storage, "storage")) return NULL;
  if (!convert_to_CvTermCriteria(pyobj_criteria, &criteria, "criteria")) return NULL;
  CvSeq* r;
  ERRWRAP(r = cvContourFromContourTree(tree, storage, criteria));
  return FROM_CvSeqPTR(r);
}

static PyObject *pycvConvert(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_src, &pyobj_dst))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvConvert(src, dst));
  Py_RETURN_NONE;
}

static PyObject *pycvConvertMaps(PyObject *self, PyObject *args)
{
  CvArr* mapx;
  PyObject *pyobj_mapx = NULL;
  CvArr* mapy;
  PyObject *pyobj_mapy = NULL;
  CvArr* mapxy;
  PyObject *pyobj_mapxy = NULL;
  CvArr* mapalpha;
  PyObject *pyobj_mapalpha = NULL;

  if (!PyArg_ParseTuple(args, "OOOO", &pyobj_mapx, &pyobj_mapy, &pyobj_mapxy, &pyobj_mapalpha))
    return NULL;
  if (!convert_to_CvArr(pyobj_mapx, &mapx, "mapx")) return NULL;
  if (!convert_to_CvArr(pyobj_mapy, &mapy, "mapy")) return NULL;
  if (!convert_to_CvArr(pyobj_mapxy, &mapxy, "mapxy")) return NULL;
  if (!convert_to_CvArr(pyobj_mapalpha, &mapalpha, "mapalpha")) return NULL;
  ERRWRAP(cvConvertMaps(mapx, mapy, mapxy, mapalpha));
  Py_RETURN_NONE;
}

static PyObject *pycvConvertScale(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  double scale = 1.0;
  double shift = 0.0;

  const char *keywords[] = { "src", "dst", "scale", "shift", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|dd", (char**)keywords, &pyobj_src, &pyobj_dst, &scale, &shift))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvConvertScale(src, dst, scale, shift));
  Py_RETURN_NONE;
}

static PyObject *pycvConvertScaleAbs(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  double scale = 1.0;
  double shift = 0.0;

  const char *keywords[] = { "src", "dst", "scale", "shift", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|dd", (char**)keywords, &pyobj_src, &pyobj_dst, &scale, &shift))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvConvertScaleAbs(src, dst, scale, shift));
  Py_RETURN_NONE;
}

static PyObject *pycvConvexHull2(PyObject *self, PyObject *args, PyObject *kw)
{
  cvarrseq points;
  PyObject *pyobj_points = NULL;
  CvMemStorage* storage;
  PyObject *pyobj_storage = NULL;
  int orientation = CV_CLOCKWISE;
  int return_points = 0;

  const char *keywords[] = { "points", "storage", "orientation", "return_points", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|ii", (char**)keywords, &pyobj_points, &pyobj_storage, &orientation, &return_points))
    return NULL;
  if (!convert_to_cvarrseq(pyobj_points, &points, "points")) return NULL;
  if (!convert_to_CvMemStorage(pyobj_storage, &storage, "storage")) return NULL;
  CvSeq* r;
  ERRWRAP(r = cvConvexHull2(points.v, storage, orientation, return_points));
  return FROM_CvSeqPTR(r);
}

static PyObject *pycvConvexityDefects(PyObject *self, PyObject *args)
{
  cvarrseq contour;
  PyObject *pyobj_contour = NULL;
  CvSeq* convexhull;
  PyObject *pyobj_convexhull = NULL;
  CvMemStorage* storage;
  PyObject *pyobj_storage = NULL;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_contour, &pyobj_convexhull, &pyobj_storage))
    return NULL;
  if (!convert_to_cvarrseq(pyobj_contour, &contour, "contour")) return NULL;
  if (!convert_to_CvSeq(pyobj_convexhull, &convexhull, "convexhull")) return NULL;
  if (!convert_to_CvMemStorage(pyobj_storage, &storage, "storage")) return NULL;
  CvSeqOfCvConvexityDefect* r;
  ERRWRAP(r = cvConvexityDefects(contour.v, convexhull, storage));
  return FROM_CvSeqOfCvConvexityDefectPTR(r);
}

static PyObject *pycvCopy(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvArr* msk = NULL;
  PyObject *pyobj_msk = NULL;

  const char *keywords[] = { "src", "dst", "msk", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|O", (char**)keywords, &pyobj_src, &pyobj_dst, &pyobj_msk))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if ((pyobj_msk != NULL) && !convert_to_CvArr(pyobj_msk, &msk, "msk")) return NULL;
  ERRWRAP(cvCopy(src, dst, msk));
  Py_RETURN_NONE;
}

static PyObject *pycvCopyMakeBorder(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvPoint offset;
  PyObject *pyobj_offset = NULL;
  int bordertype;
  CvScalar value = cvScalarAll(0);
  PyObject *pyobj_value = NULL;

  const char *keywords[] = { "src", "dst", "offset", "bordertype", "value", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOOi|O", (char**)keywords, &pyobj_src, &pyobj_dst, &pyobj_offset, &bordertype, &pyobj_value))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if (!convert_to_CvPoint(pyobj_offset, &offset, "offset")) return NULL;
  if ((pyobj_value != NULL) && !convert_to_CvScalar(pyobj_value, &value, "value")) return NULL;
  ERRWRAP(cvCopyMakeBorder(src, dst, offset, bordertype, value));
  Py_RETURN_NONE;
}

static PyObject *pycvCornerEigenValsAndVecs(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* image;
  PyObject *pyobj_image = NULL;
  CvArr* eigenvv;
  PyObject *pyobj_eigenvv = NULL;
  int block_size;
  int aperture_size = 3;

  const char *keywords[] = { "image", "eigenvv", "block_size", "aperture_size", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOi|i", (char**)keywords, &pyobj_image, &pyobj_eigenvv, &block_size, &aperture_size))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvArr(pyobj_eigenvv, &eigenvv, "eigenvv")) return NULL;
  ERRWRAP(cvCornerEigenValsAndVecs(image, eigenvv, block_size, aperture_size));
  Py_RETURN_NONE;
}

static PyObject *pycvCornerHarris(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* image;
  PyObject *pyobj_image = NULL;
  CvArr* harris_dst;
  PyObject *pyobj_harris_dst = NULL;
  int block_size;
  int aperture_size = 3;
  double k = 0.04;

  const char *keywords[] = { "image", "harris_dst", "block_size", "aperture_size", "k", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOi|id", (char**)keywords, &pyobj_image, &pyobj_harris_dst, &block_size, &aperture_size, &k))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvArr(pyobj_harris_dst, &harris_dst, "harris_dst")) return NULL;
  ERRWRAP(cvCornerHarris(image, harris_dst, block_size, aperture_size, k));
  Py_RETURN_NONE;
}

static PyObject *pycvCornerMinEigenVal(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* image;
  PyObject *pyobj_image = NULL;
  CvArr* eigenval;
  PyObject *pyobj_eigenval = NULL;
  int block_size;
  int aperture_size = 3;

  const char *keywords[] = { "image", "eigenval", "block_size", "aperture_size", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOi|i", (char**)keywords, &pyobj_image, &pyobj_eigenval, &block_size, &aperture_size))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvArr(pyobj_eigenval, &eigenval, "eigenval")) return NULL;
  ERRWRAP(cvCornerMinEigenVal(image, eigenval, block_size, aperture_size));
  Py_RETURN_NONE;
}

static PyObject *pycvCountNonZero(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_arr))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  int r;
  ERRWRAP(r = cvCountNonZero(arr));
  return FROM_int(r);
}

static PyObject *pycvCreateContourTree(PyObject *self, PyObject *args)
{
  CvSeq* contour;
  PyObject *pyobj_contour = NULL;
  CvMemStorage* storage;
  PyObject *pyobj_storage = NULL;
  double threshold;

  if (!PyArg_ParseTuple(args, "OOd", &pyobj_contour, &pyobj_storage, &threshold))
    return NULL;
  if (!convert_to_CvSeq(pyobj_contour, &contour, "contour")) return NULL;
  if (!convert_to_CvMemStorage(pyobj_storage, &storage, "storage")) return NULL;
  CvContourTree* r;
  ERRWRAP(r = cvCreateContourTree(contour, storage, threshold));
  return FROM_CvContourTreePTR(r);
}

static PyObject *pycvCreatePOSITObject(PyObject *self, PyObject *args)
{
  CvPoint3D32fs points;
  PyObject *pyobj_points = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_points))
    return NULL;
  if (!convert_to_CvPoint3D32fs(pyobj_points, &points, "points")) return NULL;
  CvPOSITObject* r;
  ERRWRAP(r = cvCreatePOSITObject(points.p,points.count));
  return FROM_CvPOSITObjectPTR(r);
}

static PyObject *pycvCreateStructuringElementEx(PyObject *self, PyObject *args, PyObject *kw)
{
  int cols;
  int rows;
  int anchor_x;
  int anchor_y;
  int shape;
  ints values = {NULL,0};
  PyObject *pyobj_values = NULL;

  const char *keywords[] = { "cols", "rows", "anchor_x", "anchor_y", "shape", "values", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "iiiii|O", (char**)keywords, &cols, &rows, &anchor_x, &anchor_y, &shape, &pyobj_values))
    return NULL;
  if ((pyobj_values != NULL) && !convert_to_ints(pyobj_values, &values, "values")) return NULL;
  IplConvKernel* r;
  ERRWRAP(r = cvCreateStructuringElementEx(cols, rows, anchor_x, anchor_y, shape, values.i));
  return FROM_IplConvKernelPTR(r);
}

static PyObject *pycvCreateSubdivDelaunay2D(PyObject *self, PyObject *args)
{
  CvRect rect;
  PyObject *pyobj_rect = NULL;
  CvMemStorage* storage;
  PyObject *pyobj_storage = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_rect, &pyobj_storage))
    return NULL;
  if (!convert_to_CvRect(pyobj_rect, &rect, "rect")) return NULL;
  if (!convert_to_CvMemStorage(pyobj_storage, &storage, "storage")) return NULL;
  CvSubdiv2D* r;
  ERRWRAP(r = cvCreateSubdivDelaunay2D(rect, storage));
  return FROM_CvSubdiv2DPTR(r);
}

static PyObject *pycvCreateVideoWriter(PyObject *self, PyObject *args, PyObject *kw)
{
  char* filename;
  int fourcc;
  double fps;
  CvSize frame_size;
  PyObject *pyobj_frame_size = NULL;
  int is_color = 1;

  const char *keywords[] = { "filename", "fourcc", "fps", "frame_size", "is_color", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "sidO|i", (char**)keywords, &filename, &fourcc, &fps, &pyobj_frame_size, &is_color))
    return NULL;
  if (!convert_to_CvSize(pyobj_frame_size, &frame_size, "frame_size")) return NULL;
  CvVideoWriter* r;
  ERRWRAP(r = cvCreateVideoWriter(filename, fourcc, fps, frame_size, is_color));
  return FROM_CvVideoWriterPTR(r);
}

static PyObject *pycvCrossProduct(PyObject *self, PyObject *args)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvArr* src2;
  PyObject *pyobj_src2 = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_src1, &pyobj_src2, &pyobj_dst))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvArr(pyobj_src2, &src2, "src2")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvCrossProduct(src1, src2, dst));
  Py_RETURN_NONE;
}

static PyObject *pycvCvtColor(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  int code;

  if (!PyArg_ParseTuple(args, "OOi", &pyobj_src, &pyobj_dst, &code))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvCvtColor(src, dst, code));
  Py_RETURN_NONE;
}

static PyObject *pycvCvtPixToPlane(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst0;
  PyObject *pyobj_dst0 = NULL;
  CvArr* dst1;
  PyObject *pyobj_dst1 = NULL;
  CvArr* dst2;
  PyObject *pyobj_dst2 = NULL;
  CvArr* dst3;
  PyObject *pyobj_dst3 = NULL;

  if (!PyArg_ParseTuple(args, "OOOOO", &pyobj_src, &pyobj_dst0, &pyobj_dst1, &pyobj_dst2, &pyobj_dst3))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst0, &dst0, "dst0")) return NULL;
  if (!convert_to_CvArr(pyobj_dst1, &dst1, "dst1")) return NULL;
  if (!convert_to_CvArr(pyobj_dst2, &dst2, "dst2")) return NULL;
  if (!convert_to_CvArr(pyobj_dst3, &dst3, "dst3")) return NULL;
  ERRWRAP(cvCvtPixToPlane(src, dst0, dst1, dst2, dst3));
  Py_RETURN_NONE;
}

static PyObject *pycvCvtScale(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  double scale = 1.0;
  double shift = 0.0;

  const char *keywords[] = { "src", "dst", "scale", "shift", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|dd", (char**)keywords, &pyobj_src, &pyobj_dst, &scale, &shift))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvCvtScale(src, dst, scale, shift));
  Py_RETURN_NONE;
}

static PyObject *pycvDCT(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  int flags;

  if (!PyArg_ParseTuple(args, "OOi", &pyobj_src, &pyobj_dst, &flags))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvDCT(src, dst, flags));
  Py_RETURN_NONE;
}

static PyObject *pycvDFT(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  int flags;
  int nonzero_rows = 0;

  const char *keywords[] = { "src", "dst", "flags", "nonzero_rows", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOi|i", (char**)keywords, &pyobj_src, &pyobj_dst, &flags, &nonzero_rows))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvDFT(src, dst, flags, nonzero_rows));
  Py_RETURN_NONE;
}

static PyObject *pycvDestroyAllWindows(PyObject *self, PyObject *args)
{

  ERRWRAP(cvDestroyAllWindows());
  Py_RETURN_NONE;
}

static PyObject *pycvDestroyWindow(PyObject *self, PyObject *args)
{
  char* name;

  if (!PyArg_ParseTuple(args, "s", &name))
    return NULL;
  ERRWRAP(cvDestroyWindow(name));
  Py_RETURN_NONE;
}

static PyObject *pycvDet(PyObject *self, PyObject *args)
{
  CvArr* mat;
  PyObject *pyobj_mat = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_mat))
    return NULL;
  if (!convert_to_CvArr(pyobj_mat, &mat, "mat")) return NULL;
  double r;
  ERRWRAP(r = cvDet(mat));
  return FROM_double(r);
}

static PyObject *pycvDilate(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  IplConvKernel* element = NULL;
  PyObject *pyobj_element = NULL;
  int iterations = 1;

  const char *keywords[] = { "src", "dst", "element", "iterations", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|Oi", (char**)keywords, &pyobj_src, &pyobj_dst, &pyobj_element, &iterations))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if ((pyobj_element != NULL) && !convert_to_IplConvKernelPTR(pyobj_element, &element, "element")) return NULL;
  ERRWRAP(cvDilate(src, dst, element, iterations));
  Py_RETURN_NONE;
}

static PyObject *pycvDistTransform(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  int distance_type = CV_DIST_L2;
  int mask_size = 3;
  floats mask = {NULL,0};
  PyObject *pyobj_mask = NULL;
  CvArr* labels = NULL;
  PyObject *pyobj_labels = NULL;

  const char *keywords[] = { "src", "dst", "distance_type", "mask_size", "mask", "labels", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|iiOO", (char**)keywords, &pyobj_src, &pyobj_dst, &distance_type, &mask_size, &pyobj_mask, &pyobj_labels))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_floats(pyobj_mask, &mask, "mask")) return NULL;
  if ((pyobj_labels != NULL) && !convert_to_CvArr(pyobj_labels, &labels, "labels")) return NULL;
  ERRWRAP(cvDistTransform(src, dst, distance_type, mask_size, mask.f, labels));
  Py_RETURN_NONE;
}

static PyObject *pycvDiv(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvArr* src2;
  PyObject *pyobj_src2 = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  double scale = 1.0;

  const char *keywords[] = { "src1", "src2", "dst", "scale", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|d", (char**)keywords, &pyobj_src1, &pyobj_src2, &pyobj_dst, &scale))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvArr(pyobj_src2, &src2, "src2")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvDiv(src1, src2, dst, scale));
  Py_RETURN_NONE;
}

static PyObject *pycvDotProduct(PyObject *self, PyObject *args)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvArr* src2;
  PyObject *pyobj_src2 = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_src1, &pyobj_src2))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvArr(pyobj_src2, &src2, "src2")) return NULL;
  double r;
  ERRWRAP(r = cvDotProduct(src1, src2));
  return FROM_double(r);
}

static PyObject *pycvDrawChessboardCorners(PyObject *self, PyObject *args)
{
  CvArr* image;
  PyObject *pyobj_image = NULL;
  CvSize pattern_size;
  PyObject *pyobj_pattern_size = NULL;
  CvPoint2D32fs corners;
  PyObject *pyobj_corners = NULL;
  int pattern_was_found;

  if (!PyArg_ParseTuple(args, "OOOi", &pyobj_image, &pyobj_pattern_size, &pyobj_corners, &pattern_was_found))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvSize(pyobj_pattern_size, &pattern_size, "pattern_size")) return NULL;
  if (!convert_to_CvPoint2D32fs(pyobj_corners, &corners, "corners")) return NULL;
  ERRWRAP(cvDrawChessboardCorners(image, pattern_size, corners.p,corners.count, pattern_was_found));
  Py_RETURN_NONE;
}

static PyObject *pycvDrawContours(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* img;
  PyObject *pyobj_img = NULL;
  CvSeq* contour;
  PyObject *pyobj_contour = NULL;
  CvScalar external_color;
  PyObject *pyobj_external_color = NULL;
  CvScalar hole_color;
  PyObject *pyobj_hole_color = NULL;
  int max_level;
  int thickness = 1;
  int line_type = 8;
  CvPoint offset = cvPoint(0,0);
  PyObject *pyobj_offset = NULL;

  const char *keywords[] = { "img", "contour", "external_color", "hole_color", "max_level", "thickness", "line_type", "offset", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOOOi|iiO", (char**)keywords, &pyobj_img, &pyobj_contour, &pyobj_external_color, &pyobj_hole_color, &max_level, &thickness, &line_type, &pyobj_offset))
    return NULL;
  if (!convert_to_CvArr(pyobj_img, &img, "img")) return NULL;
  if (!convert_to_CvSeq(pyobj_contour, &contour, "contour")) return NULL;
  if (!convert_to_CvScalar(pyobj_external_color, &external_color, "external_color")) return NULL;
  if (!convert_to_CvScalar(pyobj_hole_color, &hole_color, "hole_color")) return NULL;
  if ((pyobj_offset != NULL) && !convert_to_CvPoint(pyobj_offset, &offset, "offset")) return NULL;
  ERRWRAP(cvDrawContours(img, contour, external_color, hole_color, max_level, thickness, line_type, offset));
  Py_RETURN_NONE;
}

static PyObject *pycvEigenVV(PyObject *self, PyObject *args)
{
  CvArr* mat;
  PyObject *pyobj_mat = NULL;
  CvArr* evects;
  PyObject *pyobj_evects = NULL;
  CvArr* evals;
  PyObject *pyobj_evals = NULL;
  double eps;

  if (!PyArg_ParseTuple(args, "OOOd", &pyobj_mat, &pyobj_evects, &pyobj_evals, &eps))
    return NULL;
  if (!convert_to_CvArr(pyobj_mat, &mat, "mat")) return NULL;
  if (!convert_to_CvArr(pyobj_evects, &evects, "evects")) return NULL;
  if (!convert_to_CvArr(pyobj_evals, &evals, "evals")) return NULL;
  ERRWRAP(cvEigenVV(mat, evects, evals, eps));
  Py_RETURN_NONE;
}

static PyObject *pycvEllipse(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* img;
  PyObject *pyobj_img = NULL;
  CvPoint pt1;
  PyObject *pyobj_pt1 = NULL;
  CvSize axes;
  PyObject *pyobj_axes = NULL;
  double angle;
  double start_angle;
  double end_angle;
  CvScalar color;
  PyObject *pyobj_color = NULL;
  int thickness = 1;
  int line_type = 8;
  int shift = 0;

  const char *keywords[] = { "img", "pt1", "axes", "angle", "start_angle", "end_angle", "color", "thickness", "line_type", "shift", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOOdddO|iii", (char**)keywords, &pyobj_img, &pyobj_pt1, &pyobj_axes, &angle, &start_angle, &end_angle, &pyobj_color, &thickness, &line_type, &shift))
    return NULL;
  if (!convert_to_CvArr(pyobj_img, &img, "img")) return NULL;
  if (!convert_to_CvPoint(pyobj_pt1, &pt1, "pt1")) return NULL;
  if (!convert_to_CvSize(pyobj_axes, &axes, "axes")) return NULL;
  if (!convert_to_CvScalar(pyobj_color, &color, "color")) return NULL;
  ERRWRAP(cvEllipse(img, pt1, axes, angle, start_angle, end_angle, color, thickness, line_type, shift));
  Py_RETURN_NONE;
}

static PyObject *pycvEllipseBox(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* img;
  PyObject *pyobj_img = NULL;
  CvBox2D box;
  PyObject *pyobj_box = NULL;
  CvScalar color;
  PyObject *pyobj_color = NULL;
  int thickness = 1;
  int line_type = 8;
  int shift = 0;

  const char *keywords[] = { "img", "box", "color", "thickness", "line_type", "shift", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|iii", (char**)keywords, &pyobj_img, &pyobj_box, &pyobj_color, &thickness, &line_type, &shift))
    return NULL;
  if (!convert_to_CvArr(pyobj_img, &img, "img")) return NULL;
  if (!convert_to_CvBox2D(pyobj_box, &box, "box")) return NULL;
  if (!convert_to_CvScalar(pyobj_color, &color, "color")) return NULL;
  ERRWRAP(cvEllipseBox(img, box, color, thickness, line_type, shift));
  Py_RETURN_NONE;
}

static PyObject *pycvEqualizeHist(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_src, &pyobj_dst))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvEqualizeHist(src, dst));
  Py_RETURN_NONE;
}

static PyObject *pycvErode(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  IplConvKernel* element = NULL;
  PyObject *pyobj_element = NULL;
  int iterations = 1;

  const char *keywords[] = { "src", "dst", "element", "iterations", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|Oi", (char**)keywords, &pyobj_src, &pyobj_dst, &pyobj_element, &iterations))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if ((pyobj_element != NULL) && !convert_to_IplConvKernelPTR(pyobj_element, &element, "element")) return NULL;
  ERRWRAP(cvErode(src, dst, element, iterations));
  Py_RETURN_NONE;
}

static PyObject *pycvEstimateRigidTransform(PyObject *self, PyObject *args)
{
  CvArr* A;
  PyObject *pyobj_A = NULL;
  CvArr* B;
  PyObject *pyobj_B = NULL;
  CvMat* M;
  PyObject *pyobj_M = NULL;
  int full_affine;

  if (!PyArg_ParseTuple(args, "OOOi", &pyobj_A, &pyobj_B, &pyobj_M, &full_affine))
    return NULL;
  if (!convert_to_CvArr(pyobj_A, &A, "A")) return NULL;
  if (!convert_to_CvArr(pyobj_B, &B, "B")) return NULL;
  if (!convert_to_CvMat(pyobj_M, &M, "M")) return NULL;
  ERRWRAP(cvEstimateRigidTransform(A, B, M, full_affine));
  Py_RETURN_NONE;
}

static PyObject *pycvExp(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_src, &pyobj_dst))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvExp(src, dst));
  Py_RETURN_NONE;
}

static PyObject *pycvExtractSURF(PyObject *self, PyObject *args)
{
  CvArr* image;
  PyObject *pyobj_image = NULL;
  CvArr* mask;
  PyObject *pyobj_mask = NULL;
  CvSeqOfCvSURFPoint* keypoints;
  CvSeqOfCvSURFDescriptor* descriptors;
  CvMemStorage* storage;
  PyObject *pyobj_storage = NULL;
  CvSURFParams params;

  if (!PyArg_ParseTuple(args, "OOO(idii)", &pyobj_image, &pyobj_mask, &pyobj_storage, &params.extended, &params.hessianThreshold, &params.nOctaves, &params.nOctaveLayers))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  if (!convert_to_CvMemStorage(pyobj_storage, &storage, "storage")) return NULL;
  ERRWRAP(cvExtractSURF(image, mask, &keypoints, &descriptors, storage, params));
  return Py_BuildValue("NN", FROM_CvSeqOfCvSURFPointPTR(keypoints), FROM_CvSeqOfCvSURFDescriptorPTR(descriptors));
}

static PyObject *pycvFastArctan(PyObject *self, PyObject *args)
{
  float y;
  float x;

  if (!PyArg_ParseTuple(args, "ff", &y, &x))
    return NULL;
  float r;
  ERRWRAP(r = cvFastArctan(y, x));
  return FROM_float(r);
}

static PyObject *pycvFillConvexPoly(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* img;
  PyObject *pyobj_img = NULL;
  CvPoints pn;
  PyObject *pyobj_pn = NULL;
  CvScalar color;
  PyObject *pyobj_color = NULL;
  int line_type = 8;
  int shift = 0;

  const char *keywords[] = { "img", "pn", "color", "line_type", "shift", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|ii", (char**)keywords, &pyobj_img, &pyobj_pn, &pyobj_color, &line_type, &shift))
    return NULL;
  if (!convert_to_CvArr(pyobj_img, &img, "img")) return NULL;
  if (!convert_to_CvPoints(pyobj_pn, &pn, "pn")) return NULL;
  if (!convert_to_CvScalar(pyobj_color, &color, "color")) return NULL;
  ERRWRAP(cvFillConvexPoly(img, pn.p,pn.count, color, line_type, shift));
  Py_RETURN_NONE;
}

static PyObject *pycvFillPoly(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* img;
  PyObject *pyobj_img = NULL;
  pts_npts_contours pts;
  PyObject *pyobj_pts = NULL;
  CvScalar color;
  PyObject *pyobj_color = NULL;
  int line_type = 8;
  int shift = 0;

  const char *keywords[] = { "img", "pts", "color", "line_type", "shift", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|ii", (char**)keywords, &pyobj_img, &pyobj_pts, &pyobj_color, &line_type, &shift))
    return NULL;
  if (!convert_to_CvArr(pyobj_img, &img, "img")) return NULL;
  if (!convert_to_pts_npts_contours(pyobj_pts, &pts, "pts")) return NULL;
  if (!convert_to_CvScalar(pyobj_color, &color, "color")) return NULL;
  ERRWRAP(cvFillPoly(img, pts.pts,pts.npts,pts.contours, color, line_type, shift));
  Py_RETURN_NONE;
}

static PyObject *pycvFilter2D(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvMat* kernel;
  PyObject *pyobj_kernel = NULL;
  CvPoint anchor = cvPoint(-1,-1);
  PyObject *pyobj_anchor = NULL;

  const char *keywords[] = { "src", "dst", "kernel", "anchor", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|O", (char**)keywords, &pyobj_src, &pyobj_dst, &pyobj_kernel, &pyobj_anchor))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if (!convert_to_CvMat(pyobj_kernel, &kernel, "kernel")) return NULL;
  if ((pyobj_anchor != NULL) && !convert_to_CvPoint(pyobj_anchor, &anchor, "anchor")) return NULL;
  ERRWRAP(cvFilter2D(src, dst, kernel, anchor));
  Py_RETURN_NONE;
}

static PyObject *pycvFindCornerSubPix(PyObject *self, PyObject *args)
{
  CvArr* image;
  PyObject *pyobj_image = NULL;
  CvPoint2D32fs corners;
  PyObject *pyobj_corners = NULL;
  CvSize win;
  PyObject *pyobj_win = NULL;
  CvSize zero_zone;
  PyObject *pyobj_zero_zone = NULL;
  CvTermCriteria criteria;
  PyObject *pyobj_criteria = NULL;

  if (!PyArg_ParseTuple(args, "OOOOO", &pyobj_image, &pyobj_corners, &pyobj_win, &pyobj_zero_zone, &pyobj_criteria))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvPoint2D32fs(pyobj_corners, &corners, "corners")) return NULL;
  if (!convert_to_CvSize(pyobj_win, &win, "win")) return NULL;
  if (!convert_to_CvSize(pyobj_zero_zone, &zero_zone, "zero_zone")) return NULL;
  if (!convert_to_CvTermCriteria(pyobj_criteria, &criteria, "criteria")) return NULL;
  ERRWRAP(cvFindCornerSubPix(image, corners.p,corners.count, win, zero_zone, criteria));
  return FROM_CvPoint2D32fs(corners);
}

static PyObject *pycvFindExtrinsicCameraParams2(PyObject *self, PyObject *args)
{
  CvMat* object_points;
  PyObject *pyobj_object_points = NULL;
  CvMat* image_points;
  PyObject *pyobj_image_points = NULL;
  CvMat* intrinsic_matrix;
  PyObject *pyobj_intrinsic_matrix = NULL;
  CvMat* distortion_coeffs;
  PyObject *pyobj_distortion_coeffs = NULL;
  CvMat* rotation_vector;
  PyObject *pyobj_rotation_vector = NULL;
  CvMat* translation_vector;
  PyObject *pyobj_translation_vector = NULL;

  if (!PyArg_ParseTuple(args, "OOOOOO", &pyobj_object_points, &pyobj_image_points, &pyobj_intrinsic_matrix, &pyobj_distortion_coeffs, &pyobj_rotation_vector, &pyobj_translation_vector))
    return NULL;
  if (!convert_to_CvMat(pyobj_object_points, &object_points, "object_points")) return NULL;
  if (!convert_to_CvMat(pyobj_image_points, &image_points, "image_points")) return NULL;
  if (!convert_to_CvMat(pyobj_intrinsic_matrix, &intrinsic_matrix, "intrinsic_matrix")) return NULL;
  if (!convert_to_CvMat(pyobj_distortion_coeffs, &distortion_coeffs, "distortion_coeffs")) return NULL;
  if (!convert_to_CvMat(pyobj_rotation_vector, &rotation_vector, "rotation_vector")) return NULL;
  if (!convert_to_CvMat(pyobj_translation_vector, &translation_vector, "translation_vector")) return NULL;
  ERRWRAP(cvFindExtrinsicCameraParams2(object_points, image_points, intrinsic_matrix, distortion_coeffs, rotation_vector, translation_vector));
  Py_RETURN_NONE;
}

static PyObject *pycvFindHomography(PyObject *self, PyObject *args)
{
  CvMat* src_points;
  PyObject *pyobj_src_points = NULL;
  CvMat* dst_points;
  PyObject *pyobj_dst_points = NULL;
  CvMat* homography;
  PyObject *pyobj_homography = NULL;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_src_points, &pyobj_dst_points, &pyobj_homography))
    return NULL;
  if (!convert_to_CvMat(pyobj_src_points, &src_points, "src_points")) return NULL;
  if (!convert_to_CvMat(pyobj_dst_points, &dst_points, "dst_points")) return NULL;
  if (!convert_to_CvMat(pyobj_homography, &homography, "homography")) return NULL;
  ERRWRAP(cvFindHomography(src_points, dst_points, homography));
  return FROM_CvMat(homography);
}

static PyObject *pycvFindNearestPoint2D(PyObject *self, PyObject *args)
{
  CvSubdiv2D* subdiv;
  PyObject *pyobj_subdiv = NULL;
  CvPoint2D32f pt;
  PyObject *pyobj_pt = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_subdiv, &pyobj_pt))
    return NULL;
  if (!convert_to_CvSubdiv2DPTR(pyobj_subdiv, &subdiv, "subdiv")) return NULL;
  if (!convert_to_CvPoint2D32f(pyobj_pt, &pt, "pt")) return NULL;
  CvSubdiv2DPoint* r;
  ERRWRAP(r = cvFindNearestPoint2D(subdiv, pt));
  return FROM_CvSubdiv2DPointPTR(r);
}

static PyObject *pycvFitEllipse2(PyObject *self, PyObject *args)
{
  CvArr* points;
  PyObject *pyobj_points = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_points))
    return NULL;
  if (!convert_to_CvArr(pyobj_points, &points, "points")) return NULL;
  CvBox2D r;
  ERRWRAP(r = cvFitEllipse2(points));
  return FROM_CvBox2D(r);
}

static PyObject *pycvFlip(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst = NULL;
  PyObject *pyobj_dst = NULL;
  int flip_mode = 0;

  const char *keywords[] = { "src", "dst", "flip_mode", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "O|Oi", (char**)keywords, &pyobj_src, &pyobj_dst, &flip_mode))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if ((pyobj_dst != NULL) && !convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvFlip(src, dst, flip_mode));
  Py_RETURN_NONE;
}

static PyObject *pycvFloodFill(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* image;
  PyObject *pyobj_image = NULL;
  CvPoint seed_point;
  PyObject *pyobj_seed_point = NULL;
  CvScalar new_val;
  PyObject *pyobj_new_val = NULL;
  CvScalar lo_diff = cvScalarAll(0);
  PyObject *pyobj_lo_diff = NULL;
  CvScalar up_diff = cvScalarAll(0);
  PyObject *pyobj_up_diff = NULL;
  CvConnectedComp comp;
  int flags = 4;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "image", "seed_point", "new_val", "lo_diff", "up_diff", "flags", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|OOiO", (char**)keywords, &pyobj_image, &pyobj_seed_point, &pyobj_new_val, &pyobj_lo_diff, &pyobj_up_diff, &flags, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvPoint(pyobj_seed_point, &seed_point, "seed_point")) return NULL;
  if (!convert_to_CvScalar(pyobj_new_val, &new_val, "new_val")) return NULL;
  if ((pyobj_lo_diff != NULL) && !convert_to_CvScalar(pyobj_lo_diff, &lo_diff, "lo_diff")) return NULL;
  if ((pyobj_up_diff != NULL) && !convert_to_CvScalar(pyobj_up_diff, &up_diff, "up_diff")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvFloodFill(image, seed_point, new_val, lo_diff, up_diff, &comp, flags, mask));
  return FROM_CvConnectedComp(comp);
}

static PyObject *pycvFloor(PyObject *self, PyObject *args)
{
  double value;

  if (!PyArg_ParseTuple(args, "d", &value))
    return NULL;
  int r;
  ERRWRAP(r = cvFloor(value));
  return FROM_int(r);
}

static PyObject *pycvGEMM(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvArr* src2;
  PyObject *pyobj_src2 = NULL;
  double alpha;
  CvArr* src3;
  PyObject *pyobj_src3 = NULL;
  double beta;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  int tABC = 0;

  const char *keywords[] = { "src1", "src2", "alpha", "src3", "beta", "dst", "tABC", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOdOdO|i", (char**)keywords, &pyobj_src1, &pyobj_src2, &alpha, &pyobj_src3, &beta, &pyobj_dst, &tABC))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvArr(pyobj_src2, &src2, "src2")) return NULL;
  if (!convert_to_CvArr(pyobj_src3, &src3, "src3")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvGEMM(src1, src2, alpha, src3, beta, dst, tABC));
  Py_RETURN_NONE;
}

static PyObject *pycvGet1D(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  int idx0;

  if (!PyArg_ParseTuple(args, "Oi", &pyobj_arr, &idx0))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  CvScalar r;
  ERRWRAP(r = cvGet1D(arr, idx0));
  return FROM_CvScalar(r);
}

static PyObject *pycvGet2D(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  int idx0;
  int idx1;

  if (!PyArg_ParseTuple(args, "Oii", &pyobj_arr, &idx0, &idx1))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  CvScalar r;
  ERRWRAP(r = cvGet2D(arr, idx0, idx1));
  return FROM_CvScalar(r);
}

static PyObject *pycvGet3D(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  int idx0;
  int idx1;
  int idx2;

  if (!PyArg_ParseTuple(args, "Oiii", &pyobj_arr, &idx0, &idx1, &idx2))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  CvScalar r;
  ERRWRAP(r = cvGet3D(arr, idx0, idx1, idx2));
  return FROM_CvScalar(r);
}

static PyObject *pycvGetAffineTransform(PyObject *self, PyObject *args)
{
  CvPoint2D32f* src;
  PyObject *pyobj_src = NULL;
  CvPoint2D32f* dst;
  PyObject *pyobj_dst = NULL;
  CvMat* map_matrix;
  PyObject *pyobj_map_matrix = NULL;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_src, &pyobj_dst, &pyobj_map_matrix))
    return NULL;
  if (!convert_to_CvPoint2D32fPTR(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvPoint2D32fPTR(pyobj_dst, &dst, "dst")) return NULL;
  if (!convert_to_CvMat(pyobj_map_matrix, &map_matrix, "map_matrix")) return NULL;
  ERRWRAP(cvGetAffineTransform(src, dst, map_matrix));
  Py_RETURN_NONE;
}

static PyObject *pycvGetCaptureProperty(PyObject *self, PyObject *args)
{
  CvCapture* capture;
  PyObject *pyobj_capture = NULL;
  int property_id;

  if (!PyArg_ParseTuple(args, "Oi", &pyobj_capture, &property_id))
    return NULL;
  if (!convert_to_CvCapturePTR(pyobj_capture, &capture, "capture")) return NULL;
  double r;
  ERRWRAP(r = cvGetCaptureProperty(capture, property_id));
  return FROM_double(r);
}

static PyObject *pycvGetCentralMoment(PyObject *self, PyObject *args)
{
  CvMoments* moments;
  PyObject *pyobj_moments = NULL;
  int x_order;
  int y_order;

  if (!PyArg_ParseTuple(args, "Oii", &pyobj_moments, &x_order, &y_order))
    return NULL;
  if (!convert_to_CvMomentsPTR(pyobj_moments, &moments, "moments")) return NULL;
  double r;
  ERRWRAP(r = cvGetCentralMoment(moments, x_order, y_order));
  return FROM_double(r);
}

static PyObject *pycvGetCol(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  CvMat* submat;
  int col;

  if (!PyArg_ParseTuple(args, "Oi", &pyobj_arr, &col))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
preShareData(arr, &submat);
  ERRWRAP(cvGetCol(arr, submat, col));
  return shareData(pyobj_arr, arr, submat);
}

static PyObject *pycvGetCols(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  CvMat* submat;
  int start_col;
  int end_col;

  if (!PyArg_ParseTuple(args, "Oii", &pyobj_arr, &start_col, &end_col))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
preShareData(arr, &submat);
  ERRWRAP(cvGetCols(arr, submat, start_col, end_col));
  return shareData(pyobj_arr, arr, submat);
}

static PyObject *pycvGetDiag(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  CvMat* submat;
  int diag = 0;

  const char *keywords[] = { "arr", "diag", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "O|i", (char**)keywords, &pyobj_arr, &diag))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
preShareData(arr, &submat);
  ERRWRAP(cvGetDiag(arr, submat, diag));
  return shareData(pyobj_arr, arr, submat);
}

static PyObject *pycvGetElemType(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_arr))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  int r;
  ERRWRAP(r = cvGetElemType(arr));
  return FROM_int(r);
}

static PyObject *pycvGetImageCOI(PyObject *self, PyObject *args)
{
  IplImage* image;
  PyObject *pyobj_image = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_image))
    return NULL;
  if (!convert_to_IplImage(pyobj_image, &image, "image")) return NULL;
  int r;
  ERRWRAP(r = cvGetImageCOI(image));
  return FROM_int(r);
}

static PyObject *pycvGetImageROI(PyObject *self, PyObject *args)
{
  IplImage* image;
  PyObject *pyobj_image = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_image))
    return NULL;
  if (!convert_to_IplImage(pyobj_image, &image, "image")) return NULL;
  CvRect r;
  ERRWRAP(r = cvGetImageROI(image));
  return FROM_CvRect(r);
}

static PyObject *pycvGetND(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  ints idx;
  PyObject *pyobj_idx = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_arr, &pyobj_idx))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  if (!convert_to_ints(pyobj_idx, &idx, "idx")) return NULL;
  CvScalar r;
  ERRWRAP(r = cvGetND(arr, idx.i));
  return FROM_CvScalar(r);
}

static PyObject *pycvGetNormalizedCentralMoment(PyObject *self, PyObject *args)
{
  CvMoments* moments;
  PyObject *pyobj_moments = NULL;
  int x_order;
  int y_order;

  if (!PyArg_ParseTuple(args, "Oii", &pyobj_moments, &x_order, &y_order))
    return NULL;
  if (!convert_to_CvMomentsPTR(pyobj_moments, &moments, "moments")) return NULL;
  double r;
  ERRWRAP(r = cvGetNormalizedCentralMoment(moments, x_order, y_order));
  return FROM_double(r);
}

static PyObject *pycvGetOptimalDFTSize(PyObject *self, PyObject *args)
{
  int size0;

  if (!PyArg_ParseTuple(args, "i", &size0))
    return NULL;
  int r;
  ERRWRAP(r = cvGetOptimalDFTSize(size0));
  return FROM_int(r);
}

static PyObject *pycvGetPerspectiveTransform(PyObject *self, PyObject *args)
{
  CvPoint2D32f* src;
  PyObject *pyobj_src = NULL;
  CvPoint2D32f* dst;
  PyObject *pyobj_dst = NULL;
  CvMat* map_matrix;
  PyObject *pyobj_map_matrix = NULL;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_src, &pyobj_dst, &pyobj_map_matrix))
    return NULL;
  if (!convert_to_CvPoint2D32fPTR(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvPoint2D32fPTR(pyobj_dst, &dst, "dst")) return NULL;
  if (!convert_to_CvMat(pyobj_map_matrix, &map_matrix, "map_matrix")) return NULL;
  ERRWRAP(cvGetPerspectiveTransform(src, dst, map_matrix));
  Py_RETURN_NONE;
}

static PyObject *pycvGetQuadrangleSubPix(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvMat* map_matrix;
  PyObject *pyobj_map_matrix = NULL;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_src, &pyobj_dst, &pyobj_map_matrix))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if (!convert_to_CvMat(pyobj_map_matrix, &map_matrix, "map_matrix")) return NULL;
  ERRWRAP(cvGetQuadrangleSubPix(src, dst, map_matrix));
  Py_RETURN_NONE;
}

static PyObject *pycvGetReal1D(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  int idx0;

  if (!PyArg_ParseTuple(args, "Oi", &pyobj_arr, &idx0))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  double r;
  ERRWRAP(r = cvGetReal1D(arr, idx0));
  return FROM_double(r);
}

static PyObject *pycvGetReal2D(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  int idx0;
  int idx1;

  if (!PyArg_ParseTuple(args, "Oii", &pyobj_arr, &idx0, &idx1))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  double r;
  ERRWRAP(r = cvGetReal2D(arr, idx0, idx1));
  return FROM_double(r);
}

static PyObject *pycvGetReal3D(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  int idx0;
  int idx1;
  int idx2;

  if (!PyArg_ParseTuple(args, "Oiii", &pyobj_arr, &idx0, &idx1, &idx2))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  double r;
  ERRWRAP(r = cvGetReal3D(arr, idx0, idx1, idx2));
  return FROM_double(r);
}

static PyObject *pycvGetRealND(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  ints idx;
  PyObject *pyobj_idx = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_arr, &pyobj_idx))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  if (!convert_to_ints(pyobj_idx, &idx, "idx")) return NULL;
  double r;
  ERRWRAP(r = cvGetRealND(arr, idx.i));
  return FROM_double(r);
}

static PyObject *pycvGetRectSubPix(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvPoint2D32f center;
  PyObject *pyobj_center = NULL;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_src, &pyobj_dst, &pyobj_center))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if (!convert_to_CvPoint2D32f(pyobj_center, &center, "center")) return NULL;
  ERRWRAP(cvGetRectSubPix(src, dst, center));
  Py_RETURN_NONE;
}

static PyObject *pycvGetRow(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  CvMat* submat;
  int row;

  if (!PyArg_ParseTuple(args, "Oi", &pyobj_arr, &row))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
preShareData(arr, &submat);
  ERRWRAP(cvGetRow(arr, submat, row));
  Py_RETURN_NONE;
}

static PyObject *pycvGetRows(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  CvMat* submat;
  int start_row;
  int end_row;
  int delta_row = -1;

  const char *keywords[] = { "arr", "start_row", "end_row", "delta_row", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "Oii|i", (char**)keywords, &pyobj_arr, &start_row, &end_row, &delta_row))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
preShareData(arr, &submat);
  ERRWRAP(cvGetRows(arr, submat, start_row, end_row, delta_row));
  return shareData(pyobj_arr, arr, submat);
}

static PyObject *pycvGetSize(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_arr))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  CvSize r;
  ERRWRAP(r = cvGetSize(arr));
  return FROM_CvSize(r);
}

static PyObject *pycvGetSpatialMoment(PyObject *self, PyObject *args)
{
  CvMoments* moments;
  PyObject *pyobj_moments = NULL;
  int x_order;
  int y_order;

  if (!PyArg_ParseTuple(args, "Oii", &pyobj_moments, &x_order, &y_order))
    return NULL;
  if (!convert_to_CvMomentsPTR(pyobj_moments, &moments, "moments")) return NULL;
  double r;
  ERRWRAP(r = cvGetSpatialMoment(moments, x_order, y_order));
  return FROM_double(r);
}

static PyObject *pycvGetStarKeypoints(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* image;
  PyObject *pyobj_image = NULL;
  CvMemStorage* storage;
  PyObject *pyobj_storage = NULL;
  CvStarDetectorParams params = cvStarDetectorParams();
  PyObject *pyobj_params = NULL;

  const char *keywords[] = { "image", "storage", "params", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|O", (char**)keywords, &pyobj_image, &pyobj_storage, &pyobj_params))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvMemStorage(pyobj_storage, &storage, "storage")) return NULL;
  if ((pyobj_params != NULL) && !convert_to_CvStarDetectorParams(pyobj_params, &params, "params")) return NULL;
  CvSeqOfCvStarKeypoint* r;
  ERRWRAP(r = cvGetStarKeypoints(image, storage, params));
  return FROM_CvSeqOfCvStarKeypointPTR(r);
}

static PyObject *pycvGetSubRect(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  CvMat* submat;
  CvRect rect;
  PyObject *pyobj_rect = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_arr, &pyobj_rect))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
preShareData(arr, &submat);
  if (!convert_to_CvRect(pyobj_rect, &rect, "rect")) return NULL;
  ERRWRAP(cvGetSubRect(arr, submat, rect));
  return shareData(pyobj_arr, arr, submat);
}

static PyObject *pycvGetTextSize(PyObject *self, PyObject *args)
{
  char* text_string;
  CvFont* font;
  PyObject *pyobj_font = NULL;
  CvSize text_size;
  int baseline;

  if (!PyArg_ParseTuple(args, "sO", &text_string, &pyobj_font))
    return NULL;
  if (!convert_to_CvFontPTR(pyobj_font, &font, "font")) return NULL;
  ERRWRAP(cvGetTextSize(text_string, font, &text_size, &baseline));
  return Py_BuildValue("NN", FROM_CvSize(text_size), FROM_int(baseline));
}

static PyObject *pycvGetTrackbarPos(PyObject *self, PyObject *args)
{
  char* trackbar_name;
  char* window_name;

  if (!PyArg_ParseTuple(args, "ss", &trackbar_name, &window_name))
    return NULL;
  ERRWRAP(cvGetTrackbarPos(trackbar_name, window_name));
  Py_RETURN_NONE;
}

static PyObject *pycvGoodFeaturesToTrack(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* image;
  PyObject *pyobj_image = NULL;
  CvArr* eig_image;
  PyObject *pyobj_eig_image = NULL;
  CvArr* temp_image;
  PyObject *pyobj_temp_image = NULL;
  cvpoint2d32f_count corners;
  PyObject *pyobj_corners = NULL;
  double quality_level;
  double min_distance;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;
  int block_size = 3;
  int use_harris = 0;
  double k = 0.04;

  const char *keywords[] = { "image", "eig_image", "temp_image", "corners", "quality_level", "min_distance", "mask", "block_size", "use_harris", "k", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOOOdd|Oiid", (char**)keywords, &pyobj_image, &pyobj_eig_image, &pyobj_temp_image, &pyobj_corners, &quality_level, &min_distance, &pyobj_mask, &block_size, &use_harris, &k))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvArr(pyobj_eig_image, &eig_image, "eig_image")) return NULL;
  if (!convert_to_CvArr(pyobj_temp_image, &temp_image, "temp_image")) return NULL;
  if (!convert_to_cvpoint2d32f_count(pyobj_corners, &corners, "corners")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvGoodFeaturesToTrack(image, eig_image, temp_image, corners.points,&corners.count, quality_level, min_distance, mask, block_size, use_harris, k));
  return FROM_cvpoint2d32f_count(corners);
}

static PyObject *pycvGrabFrame(PyObject *self, PyObject *args)
{
  CvCapture* capture;
  PyObject *pyobj_capture = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_capture))
    return NULL;
  if (!convert_to_CvCapturePTR(pyobj_capture, &capture, "capture")) return NULL;
  int r;
  ERRWRAP(r = cvGrabFrame(capture));
  return FROM_int(r);
}

static PyObject *pycvHaarDetectObjects(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* image;
  PyObject *pyobj_image = NULL;
  CvHaarClassifierCascade* cascade;
  PyObject *pyobj_cascade = NULL;
  CvMemStorage* storage;
  PyObject *pyobj_storage = NULL;
  double scale_factor = 1.1;
  int min_neighbors = 3;
  int flags = 0;

  const char *keywords[] = { "image", "cascade", "storage", "scale_factor", "min_neighbors", "flags", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|dii", (char**)keywords, &pyobj_image, &pyobj_cascade, &pyobj_storage, &scale_factor, &min_neighbors, &flags))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvHaarClassifierCascadePTR(pyobj_cascade, &cascade, "cascade")) return NULL;
  if (!convert_to_CvMemStorage(pyobj_storage, &storage, "storage")) return NULL;
  CvSeqOfCvAvgComp* r;
  ERRWRAP(r = cvHaarDetectObjects(image, cascade, storage, scale_factor, min_neighbors, flags));
  return FROM_CvSeqOfCvAvgCompPTR(r);
}

static PyObject *pycvHoughCircles(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* image;
  PyObject *pyobj_image = NULL;
  CvMat* circle_storage;
  PyObject *pyobj_circle_storage = NULL;
  int method;
  double dp;
  double min_dist;
  double param1 = 100;
  double param2 = 100;
  int min_radius = 0;
  int max_radius = 0;

  const char *keywords[] = { "image", "circle_storage", "method", "dp", "min_dist", "param1", "param2", "min_radius", "max_radius", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOidd|ddii", (char**)keywords, &pyobj_image, &pyobj_circle_storage, &method, &dp, &min_dist, &param1, &param2, &min_radius, &max_radius))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvMat(pyobj_circle_storage, &circle_storage, "circle_storage")) return NULL;
  ERRWRAP(cvHoughCircles(image, circle_storage, method, dp, min_dist, param1, param2, min_radius, max_radius));
  Py_RETURN_NONE;
}

static PyObject *pycvHoughLines2(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* image;
  PyObject *pyobj_image = NULL;
  CvMemStorage* storage;
  PyObject *pyobj_storage = NULL;
  int method;
  double rho;
  double theta;
  int threshold;
  double param1 = 0;
  double param2 = 0;

  const char *keywords[] = { "image", "storage", "method", "rho", "theta", "threshold", "param1", "param2", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOiddi|dd", (char**)keywords, &pyobj_image, &pyobj_storage, &method, &rho, &theta, &threshold, &param1, &param2))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvMemStorage(pyobj_storage, &storage, "storage")) return NULL;
  CvSeq* r;
  ERRWRAP(r = cvHoughLines2(image, storage, method, rho, theta, threshold, param1, param2));
  return FROM_CvSeqPTR(r);
}

static PyObject *pycvInRange(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* lower;
  PyObject *pyobj_lower = NULL;
  CvArr* upper;
  PyObject *pyobj_upper = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;

  if (!PyArg_ParseTuple(args, "OOOO", &pyobj_src, &pyobj_lower, &pyobj_upper, &pyobj_dst))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_lower, &lower, "lower")) return NULL;
  if (!convert_to_CvArr(pyobj_upper, &upper, "upper")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvInRange(src, lower, upper, dst));
  Py_RETURN_NONE;
}

static PyObject *pycvInRangeS(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvScalar lower;
  PyObject *pyobj_lower = NULL;
  CvScalar upper;
  PyObject *pyobj_upper = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;

  if (!PyArg_ParseTuple(args, "OOOO", &pyobj_src, &pyobj_lower, &pyobj_upper, &pyobj_dst))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvScalar(pyobj_lower, &lower, "lower")) return NULL;
  if (!convert_to_CvScalar(pyobj_upper, &upper, "upper")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvInRangeS(src, lower, upper, dst));
  Py_RETURN_NONE;
}

static PyObject *pycvInitFont(PyObject *self, PyObject *args, PyObject *kw)
{
  CvFont font;
  int font_face;
  double hscale;
  double vscale;
  double shear = 0;
  int thickness = 1;
  int line_type = 8;

  const char *keywords[] = { "font_face", "hscale", "vscale", "shear", "thickness", "line_type", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "idd|dii", (char**)keywords, &font_face, &hscale, &vscale, &shear, &thickness, &line_type))
    return NULL;
  ERRWRAP(cvInitFont(&font, font_face, hscale, vscale, shear, thickness, line_type));
  return FROM_CvFont(font);
}

static PyObject *pycvInitUndistortMap(PyObject *self, PyObject *args)
{
  CvMat* camera_matrix;
  PyObject *pyobj_camera_matrix = NULL;
  CvMat* distortion_coeffs;
  PyObject *pyobj_distortion_coeffs = NULL;
  CvArr* mapx;
  PyObject *pyobj_mapx = NULL;
  CvArr* mapy;
  PyObject *pyobj_mapy = NULL;

  if (!PyArg_ParseTuple(args, "OOOO", &pyobj_camera_matrix, &pyobj_distortion_coeffs, &pyobj_mapx, &pyobj_mapy))
    return NULL;
  if (!convert_to_CvMat(pyobj_camera_matrix, &camera_matrix, "camera_matrix")) return NULL;
  if (!convert_to_CvMat(pyobj_distortion_coeffs, &distortion_coeffs, "distortion_coeffs")) return NULL;
  if (!convert_to_CvArr(pyobj_mapx, &mapx, "mapx")) return NULL;
  if (!convert_to_CvArr(pyobj_mapy, &mapy, "mapy")) return NULL;
  ERRWRAP(cvInitUndistortMap(camera_matrix, distortion_coeffs, mapx, mapy));
  Py_RETURN_NONE;
}

static PyObject *pycvInitUndistortRectifyMap(PyObject *self, PyObject *args)
{
  CvMat* camera_matrix;
  PyObject *pyobj_camera_matrix = NULL;
  CvMat* dist_coeffs;
  PyObject *pyobj_dist_coeffs = NULL;
  CvMat* R;
  PyObject *pyobj_R = NULL;
  CvMat* new_camera_matrix;
  PyObject *pyobj_new_camera_matrix = NULL;
  CvArr* mapx;
  PyObject *pyobj_mapx = NULL;
  CvArr* mapy;
  PyObject *pyobj_mapy = NULL;

  if (!PyArg_ParseTuple(args, "OOOOOO", &pyobj_camera_matrix, &pyobj_dist_coeffs, &pyobj_R, &pyobj_new_camera_matrix, &pyobj_mapx, &pyobj_mapy))
    return NULL;
  if (!convert_to_CvMat(pyobj_camera_matrix, &camera_matrix, "camera_matrix")) return NULL;
  if (!convert_to_CvMat(pyobj_dist_coeffs, &dist_coeffs, "dist_coeffs")) return NULL;
  if (!convert_to_CvMat(pyobj_R, &R, "R")) return NULL;
  if (!convert_to_CvMat(pyobj_new_camera_matrix, &new_camera_matrix, "new_camera_matrix")) return NULL;
  if (!convert_to_CvArr(pyobj_mapx, &mapx, "mapx")) return NULL;
  if (!convert_to_CvArr(pyobj_mapy, &mapy, "mapy")) return NULL;
  ERRWRAP(cvInitUndistortRectifyMap(camera_matrix, dist_coeffs, R, new_camera_matrix, mapx, mapy));
  Py_RETURN_NONE;
}

static PyObject *pycvInpaint(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* mask;
  PyObject *pyobj_mask = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  double inpaintRadius;
  int flags;

  if (!PyArg_ParseTuple(args, "OOOdi", &pyobj_src, &pyobj_mask, &pyobj_dst, &inpaintRadius, &flags))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvInpaint(src, mask, dst, inpaintRadius, flags));
  Py_RETURN_NONE;
}

static PyObject *pycvIntegral(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* image;
  PyObject *pyobj_image = NULL;
  CvArr* sum;
  PyObject *pyobj_sum = NULL;
  CvArr* sqsum = NULL;
  PyObject *pyobj_sqsum = NULL;
  CvArr* tilted_sum = NULL;
  PyObject *pyobj_tilted_sum = NULL;

  const char *keywords[] = { "image", "sum", "sqsum", "tilted_sum", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|OO", (char**)keywords, &pyobj_image, &pyobj_sum, &pyobj_sqsum, &pyobj_tilted_sum))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvArr(pyobj_sum, &sum, "sum")) return NULL;
  if ((pyobj_sqsum != NULL) && !convert_to_CvArr(pyobj_sqsum, &sqsum, "sqsum")) return NULL;
  if ((pyobj_tilted_sum != NULL) && !convert_to_CvArr(pyobj_tilted_sum, &tilted_sum, "tilted_sum")) return NULL;
  ERRWRAP(cvIntegral(image, sum, sqsum, tilted_sum));
  Py_RETURN_NONE;
}

static PyObject *pycvInvSqrt(PyObject *self, PyObject *args)
{
  float value;

  if (!PyArg_ParseTuple(args, "f", &value))
    return NULL;
  float r;
  ERRWRAP(r = cvInvSqrt(value));
  return FROM_float(r);
}

static PyObject *pycvInvert(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  int method = CV_LU;

  const char *keywords[] = { "src", "dst", "method", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|i", (char**)keywords, &pyobj_src, &pyobj_dst, &method))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  double r;
  ERRWRAP(r = cvInvert(src, dst, method));
  return FROM_double(r);
}

static PyObject *pycvIsInf(PyObject *self, PyObject *args)
{
  double value;

  if (!PyArg_ParseTuple(args, "d", &value))
    return NULL;
  int r;
  ERRWRAP(r = cvIsInf(value));
  return FROM_int(r);
}

static PyObject *pycvIsNaN(PyObject *self, PyObject *args)
{
  double value;

  if (!PyArg_ParseTuple(args, "d", &value))
    return NULL;
  int r;
  ERRWRAP(r = cvIsNaN(value));
  return FROM_int(r);
}

static PyObject *pycvKMeans2(PyObject *self, PyObject *args)
{
  CvArr* samples;
  PyObject *pyobj_samples = NULL;
  int cluster_count;
  CvArr* labels;
  PyObject *pyobj_labels = NULL;
  CvTermCriteria termcrit;
  PyObject *pyobj_termcrit = NULL;

  if (!PyArg_ParseTuple(args, "OiOO", &pyobj_samples, &cluster_count, &pyobj_labels, &pyobj_termcrit))
    return NULL;
  if (!convert_to_CvArr(pyobj_samples, &samples, "samples")) return NULL;
  if (!convert_to_CvArr(pyobj_labels, &labels, "labels")) return NULL;
  if (!convert_to_CvTermCriteria(pyobj_termcrit, &termcrit, "termcrit")) return NULL;
  ERRWRAP(cvKMeans2(samples, cluster_count, labels, termcrit));
  Py_RETURN_NONE;
}

static PyObject *pycvLUT(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvArr* lut;
  PyObject *pyobj_lut = NULL;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_src, &pyobj_dst, &pyobj_lut))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if (!convert_to_CvArr(pyobj_lut, &lut, "lut")) return NULL;
  ERRWRAP(cvLUT(src, dst, lut));
  Py_RETURN_NONE;
}

static PyObject *pycvLaplace(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  int aperture_size = 3;

  const char *keywords[] = { "src", "dst", "aperture_size", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|i", (char**)keywords, &pyobj_src, &pyobj_dst, &aperture_size))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvLaplace(src, dst, aperture_size));
  Py_RETURN_NONE;
}

static PyObject *pycvLine(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* img;
  PyObject *pyobj_img = NULL;
  CvPoint pt1;
  PyObject *pyobj_pt1 = NULL;
  CvPoint pt2;
  PyObject *pyobj_pt2 = NULL;
  CvScalar color;
  PyObject *pyobj_color = NULL;
  int thickness = 1;
  int line_type = 8;
  int shift = 0;

  const char *keywords[] = { "img", "pt1", "pt2", "color", "thickness", "line_type", "shift", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOOO|iii", (char**)keywords, &pyobj_img, &pyobj_pt1, &pyobj_pt2, &pyobj_color, &thickness, &line_type, &shift))
    return NULL;
  if (!convert_to_CvArr(pyobj_img, &img, "img")) return NULL;
  if (!convert_to_CvPoint(pyobj_pt1, &pt1, "pt1")) return NULL;
  if (!convert_to_CvPoint(pyobj_pt2, &pt2, "pt2")) return NULL;
  if (!convert_to_CvScalar(pyobj_color, &color, "color")) return NULL;
  ERRWRAP(cvLine(img, pt1, pt2, color, thickness, line_type, shift));
  Py_RETURN_NONE;
}

static PyObject *pycvLoad(PyObject *self, PyObject *args, PyObject *kw)
{
  char* filename;
  CvMemStorage* storage = NULL;
  PyObject *pyobj_storage = NULL;
  char* name = NULL;

  const char *keywords[] = { "filename", "storage", "name", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "s|Os", (char**)keywords, &filename, &pyobj_storage, &name))
    return NULL;
  if ((pyobj_storage != NULL) && !convert_to_CvMemStorage(pyobj_storage, &storage, "storage")) return NULL;
  generic r;
  ERRWRAP(r = cvLoad(filename, storage, name));
  return FROM_generic(r);
}

static PyObject *pycvLog(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_src, &pyobj_dst))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvLog(src, dst));
  Py_RETURN_NONE;
}

static PyObject *pycvLogPolar(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvPoint2D32f center;
  PyObject *pyobj_center = NULL;
  double M;
  int flags = CV_INTER_LINEAR+CV_WARP_FILL_OUTLIERS;

  const char *keywords[] = { "src", "dst", "center", "M", "flags", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOOd|i", (char**)keywords, &pyobj_src, &pyobj_dst, &pyobj_center, &M, &flags))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if (!convert_to_CvPoint2D32f(pyobj_center, &center, "center")) return NULL;
  ERRWRAP(cvLogPolar(src, dst, center, M, flags));
  Py_RETURN_NONE;
}

static PyObject *pycvMahalonobis(PyObject *self, PyObject *args)
{
  CvArr* vec1;
  PyObject *pyobj_vec1 = NULL;
  CvArr* vec2;
  PyObject *pyobj_vec2 = NULL;
  CvArr* mat;
  PyObject *pyobj_mat = NULL;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_vec1, &pyobj_vec2, &pyobj_mat))
    return NULL;
  if (!convert_to_CvArr(pyobj_vec1, &vec1, "vec1")) return NULL;
  if (!convert_to_CvArr(pyobj_vec2, &vec2, "vec2")) return NULL;
  if (!convert_to_CvArr(pyobj_mat, &mat, "mat")) return NULL;
  ERRWRAP(cvMahalonobis(vec1, vec2, mat));
  Py_RETURN_NONE;
}

static PyObject *pycvMatMul(PyObject *self, PyObject *args)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvArr* src2;
  PyObject *pyobj_src2 = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_src1, &pyobj_src2, &pyobj_dst))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvArr(pyobj_src2, &src2, "src2")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvMatMul(src1, src2, dst));
  Py_RETURN_NONE;
}

static PyObject *pycvMatMulAdd(PyObject *self, PyObject *args)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvArr* src2;
  PyObject *pyobj_src2 = NULL;
  CvArr* src3;
  PyObject *pyobj_src3 = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;

  if (!PyArg_ParseTuple(args, "OOOO", &pyobj_src1, &pyobj_src2, &pyobj_src3, &pyobj_dst))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvArr(pyobj_src2, &src2, "src2")) return NULL;
  if (!convert_to_CvArr(pyobj_src3, &src3, "src3")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvMatMulAdd(src1, src2, src3, dst));
  Py_RETURN_NONE;
}

static PyObject *pycvMatchContourTrees(PyObject *self, PyObject *args)
{
  CvContourTree* tree1;
  PyObject *pyobj_tree1 = NULL;
  CvContourTree* tree2;
  PyObject *pyobj_tree2 = NULL;
  int method;
  double threshold;

  if (!PyArg_ParseTuple(args, "OOid", &pyobj_tree1, &pyobj_tree2, &method, &threshold))
    return NULL;
  if (!convert_to_CvContourTreePTR(pyobj_tree1, &tree1, "tree1")) return NULL;
  if (!convert_to_CvContourTreePTR(pyobj_tree2, &tree2, "tree2")) return NULL;
  double r;
  ERRWRAP(r = cvMatchContourTrees(tree1, tree2, method, threshold));
  return FROM_double(r);
}

static PyObject *pycvMatchShapes(PyObject *self, PyObject *args, PyObject *kw)
{
  CvSeq* object1;
  PyObject *pyobj_object1 = NULL;
  CvSeq* object2;
  PyObject *pyobj_object2 = NULL;
  int method;
  double parameter = 0;

  const char *keywords[] = { "object1", "object2", "method", "parameter", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOi|d", (char**)keywords, &pyobj_object1, &pyobj_object2, &method, &parameter))
    return NULL;
  if (!convert_to_CvSeq(pyobj_object1, &object1, "object1")) return NULL;
  if (!convert_to_CvSeq(pyobj_object2, &object2, "object2")) return NULL;
  ERRWRAP(cvMatchShapes(object1, object2, method, parameter));
  Py_RETURN_NONE;
}

static PyObject *pycvMatchTemplate(PyObject *self, PyObject *args)
{
  CvArr* image;
  PyObject *pyobj_image = NULL;
  CvArr* templ;
  PyObject *pyobj_templ = NULL;
  CvArr* result;
  PyObject *pyobj_result = NULL;
  int method;

  if (!PyArg_ParseTuple(args, "OOOi", &pyobj_image, &pyobj_templ, &pyobj_result, &method))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvArr(pyobj_templ, &templ, "templ")) return NULL;
  if (!convert_to_CvArr(pyobj_result, &result, "result")) return NULL;
  ERRWRAP(cvMatchTemplate(image, templ, result, method));
  Py_RETURN_NONE;
}

static PyObject *pycvMax(PyObject *self, PyObject *args)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvArr* src2;
  PyObject *pyobj_src2 = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_src1, &pyobj_src2, &pyobj_dst))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvArr(pyobj_src2, &src2, "src2")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvMax(src1, src2, dst));
  Py_RETURN_NONE;
}

static PyObject *pycvMaxRect(PyObject *self, PyObject *args)
{
  CvRect* rect1;
  PyObject *pyobj_rect1 = NULL;
  CvRect* rect2;
  PyObject *pyobj_rect2 = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_rect1, &pyobj_rect2))
    return NULL;
  if (!convert_to_CvRectPTR(pyobj_rect1, &rect1, "rect1")) return NULL;
  if (!convert_to_CvRectPTR(pyobj_rect2, &rect2, "rect2")) return NULL;
  CvRect r;
  ERRWRAP(r = cvMaxRect(rect1, rect2));
  return FROM_CvRect(r);
}

static PyObject *pycvMaxS(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  double value;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;

  if (!PyArg_ParseTuple(args, "OdO", &pyobj_src, &value, &pyobj_dst))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvMaxS(src, value, dst));
  Py_RETURN_NONE;
}

static PyObject *pycvMeanShift(PyObject *self, PyObject *args)
{
  CvArr* prob_image;
  PyObject *pyobj_prob_image = NULL;
  CvRect window;
  PyObject *pyobj_window = NULL;
  CvTermCriteria criteria;
  PyObject *pyobj_criteria = NULL;
  CvConnectedComp comp;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_prob_image, &pyobj_window, &pyobj_criteria))
    return NULL;
  if (!convert_to_CvArr(pyobj_prob_image, &prob_image, "prob_image")) return NULL;
  if (!convert_to_CvRect(pyobj_window, &window, "window")) return NULL;
  if (!convert_to_CvTermCriteria(pyobj_criteria, &criteria, "criteria")) return NULL;
  ERRWRAP(cvMeanShift(prob_image, window, criteria, &comp));
  return FROM_CvConnectedComp(comp);
}

static PyObject *pycvMerge(PyObject *self, PyObject *args)
{
  CvArr* src0;
  PyObject *pyobj_src0 = NULL;
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvArr* src2;
  PyObject *pyobj_src2 = NULL;
  CvArr* src3;
  PyObject *pyobj_src3 = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;

  if (!PyArg_ParseTuple(args, "OOOOO", &pyobj_src0, &pyobj_src1, &pyobj_src2, &pyobj_src3, &pyobj_dst))
    return NULL;
  if (!convert_to_CvArr(pyobj_src0, &src0, "src0")) return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvArr(pyobj_src2, &src2, "src2")) return NULL;
  if (!convert_to_CvArr(pyobj_src3, &src3, "src3")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvMerge(src0, src1, src2, src3, dst));
  Py_RETURN_NONE;
}

static PyObject *pycvMin(PyObject *self, PyObject *args)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvArr* src2;
  PyObject *pyobj_src2 = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_src1, &pyobj_src2, &pyobj_dst))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvArr(pyobj_src2, &src2, "src2")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvMin(src1, src2, dst));
  Py_RETURN_NONE;
}

static PyObject *pycvMinAreaRect2(PyObject *self, PyObject *args)
{
  cvarrseq points;
  PyObject *pyobj_points = NULL;
  CvMemStorage* storage;
  PyObject *pyobj_storage = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_points, &pyobj_storage))
    return NULL;
  if (!convert_to_cvarrseq(pyobj_points, &points, "points")) return NULL;
  if (!convert_to_CvMemStorage(pyobj_storage, &storage, "storage")) return NULL;
  CvBox2D r;
  ERRWRAP(r = cvMinAreaRect2(points.v, storage));
  return FROM_CvBox2D(r);
}

static PyObject *pycvMinEnclosingCircle(PyObject *self, PyObject *args)
{
  cvarrseq points;
  PyObject *pyobj_points = NULL;
  CvPoint2D32f center;
  float radius;

  if (!PyArg_ParseTuple(args, "O", &pyobj_points))
    return NULL;
  if (!convert_to_cvarrseq(pyobj_points, &points, "points")) return NULL;
  int r;
  ERRWRAP(r = cvMinEnclosingCircle(points.v, &center, &radius));
  return Py_BuildValue("NNN", FROM_int(r), FROM_CvPoint2D32f(center), FROM_float(radius));
}

static PyObject *pycvMinMaxLoc(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  double min_val;
  double max_val;
  CvPoint min_loc;
  CvPoint max_loc;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "arr", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "O|O", (char**)keywords, &pyobj_arr, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvMinMaxLoc(arr, &min_val, &max_val, &min_loc, &max_loc, mask));
  return Py_BuildValue("NNNN", FROM_double(min_val), FROM_double(max_val), FROM_CvPoint(min_loc), FROM_CvPoint(max_loc));
}

static PyObject *pycvMinS(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  double value;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;

  if (!PyArg_ParseTuple(args, "OdO", &pyobj_src, &value, &pyobj_dst))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvMinS(src, value, dst));
  Py_RETURN_NONE;
}

static PyObject *pycvMixChannels(PyObject *self, PyObject *args)
{
  cvarr_count src;
  PyObject *pyobj_src = NULL;
  cvarr_count dst;
  PyObject *pyobj_dst = NULL;
  intpair from_to;
  PyObject *pyobj_from_to = NULL;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_src, &pyobj_dst, &pyobj_from_to))
    return NULL;
  if (!convert_to_cvarr_count(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_cvarr_count(pyobj_dst, &dst, "dst")) return NULL;
  if (!convert_to_intpair(pyobj_from_to, &from_to, "from_to")) return NULL;
  ERRWRAP(cvMixChannels((const CvArr **)src.cvarr,src.count, dst.cvarr,dst.count, from_to.pairs,from_to.count));
  Py_RETURN_NONE;
}

static PyObject *pycvMoments(PyObject *self, PyObject *args, PyObject *kw)
{
  cvarrseq arr;
  PyObject *pyobj_arr = NULL;
  CvMoments moments;
  int binary = 0;

  const char *keywords[] = { "arr", "binary", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "O|i", (char**)keywords, &pyobj_arr, &binary))
    return NULL;
  if (!convert_to_cvarrseq(pyobj_arr, &arr, "arr")) return NULL;
  ERRWRAP(cvMoments(arr.v, &moments, binary));
  return FROM_CvMoments(moments);
}

static PyObject *pycvMorphologyEx(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvArr* temp;
  PyObject *pyobj_temp = NULL;
  IplConvKernel* element;
  PyObject *pyobj_element = NULL;
  int operation;
  int iterations = 1;

  const char *keywords[] = { "src", "dst", "temp", "element", "operation", "iterations", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOOOi|i", (char**)keywords, &pyobj_src, &pyobj_dst, &pyobj_temp, &pyobj_element, &operation, &iterations))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if (!convert_to_CvArr(pyobj_temp, &temp, "temp")) return NULL;
  if (!convert_to_IplConvKernelPTR(pyobj_element, &element, "element")) return NULL;
  ERRWRAP(cvMorphologyEx(src, dst, temp, element, operation, iterations));
  Py_RETURN_NONE;
}

static PyObject *pycvMoveWindow(PyObject *self, PyObject *args)
{
  char* name;
  int x;
  int y;

  if (!PyArg_ParseTuple(args, "sii", &name, &x, &y))
    return NULL;
  ERRWRAP(cvMoveWindow(name, x, y));
  Py_RETURN_NONE;
}

static PyObject *pycvMul(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvArr* src2;
  PyObject *pyobj_src2 = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  double scale = 1.0;

  const char *keywords[] = { "src1", "src2", "dst", "scale", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|d", (char**)keywords, &pyobj_src1, &pyobj_src2, &pyobj_dst, &scale))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvArr(pyobj_src2, &src2, "src2")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvMul(src1, src2, dst, scale));
  Py_RETURN_NONE;
}

static PyObject *pycvMulSpectrums(PyObject *self, PyObject *args)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvArr* src2;
  PyObject *pyobj_src2 = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  int flags;

  if (!PyArg_ParseTuple(args, "OOOi", &pyobj_src1, &pyobj_src2, &pyobj_dst, &flags))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvArr(pyobj_src2, &src2, "src2")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvMulSpectrums(src1, src2, dst, flags));
  Py_RETURN_NONE;
}

static PyObject *pycvMulTransposed(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  int order;
  CvArr* delta = NULL;
  PyObject *pyobj_delta = NULL;

  const char *keywords[] = { "src", "dst", "order", "delta", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOi|O", (char**)keywords, &pyobj_src, &pyobj_dst, &order, &pyobj_delta))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if ((pyobj_delta != NULL) && !convert_to_CvArr(pyobj_delta, &delta, "delta")) return NULL;
  ERRWRAP(cvMulTransposed(src, dst, order, delta));
  Py_RETURN_NONE;
}

static PyObject *pycvMultiplyAcc(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* image1;
  PyObject *pyobj_image1 = NULL;
  CvArr* image2;
  PyObject *pyobj_image2 = NULL;
  CvArr* acc;
  PyObject *pyobj_acc = NULL;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "image1", "image2", "acc", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|O", (char**)keywords, &pyobj_image1, &pyobj_image2, &pyobj_acc, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArr(pyobj_image1, &image1, "image1")) return NULL;
  if (!convert_to_CvArr(pyobj_image2, &image2, "image2")) return NULL;
  if (!convert_to_CvArr(pyobj_acc, &acc, "acc")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvMultiplyAcc(image1, image2, acc, mask));
  Py_RETURN_NONE;
}

static PyObject *pycvNamedWindow(PyObject *self, PyObject *args, PyObject *kw)
{
  char* name;
  int flags = CV_WINDOW_AUTOSIZE;

  const char *keywords[] = { "name", "flags", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "s|i", (char**)keywords, &name, &flags))
    return NULL;
  ERRWRAP(cvNamedWindow(name, flags));
  Py_RETURN_NONE;
}

static PyObject *pycvNorm(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* arr1;
  PyObject *pyobj_arr1 = NULL;
  CvArr* arr2;
  PyObject *pyobj_arr2 = NULL;
  int norm_type = CV_L2;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "arr1", "arr2", "norm_type", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|iO", (char**)keywords, &pyobj_arr1, &pyobj_arr2, &norm_type, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr1, &arr1, "arr1")) return NULL;
  if (!convert_to_CvArr(pyobj_arr2, &arr2, "arr2")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  double r;
  ERRWRAP(r = cvNorm(arr1, arr2, norm_type, mask));
  return FROM_double(r);
}

static PyObject *pycvNormalize(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  double a = 1.0;
  double b = 0.0;
  int norm_type = CV_L2;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "src", "dst", "a", "b", "norm_type", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|ddiO", (char**)keywords, &pyobj_src, &pyobj_dst, &a, &b, &norm_type, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvNormalize(src, dst, a, b, norm_type, mask));
  Py_RETURN_NONE;
}

static PyObject *pycvNormalizeHist(PyObject *self, PyObject *args)
{
  CvHistogram* hist;
  PyObject *pyobj_hist = NULL;
  double factor;

  if (!PyArg_ParseTuple(args, "Od", &pyobj_hist, &factor))
    return NULL;
  if (!convert_to_CvHistogram(pyobj_hist, &hist, "hist")) return NULL;
  ERRWRAP(cvNormalizeHist(hist, factor));
  Py_RETURN_NONE;
}

static PyObject *pycvNot(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_src, &pyobj_dst))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvNot(src, dst));
  Py_RETURN_NONE;
}

static PyObject *pycvOr(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvArr* src2;
  PyObject *pyobj_src2 = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "src1", "src2", "dst", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|O", (char**)keywords, &pyobj_src1, &pyobj_src2, &pyobj_dst, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvArr(pyobj_src2, &src2, "src2")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvOr(src1, src2, dst, mask));
  Py_RETURN_NONE;
}

static PyObject *pycvOrS(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvScalar value;
  PyObject *pyobj_value = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "src1", "value", "dst", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|O", (char**)keywords, &pyobj_src1, &pyobj_value, &pyobj_dst, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvScalar(pyobj_value, &value, "value")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvOrS(src1, value, dst, mask));
  Py_RETURN_NONE;
}

static PyObject *pycvPOSIT(PyObject *self, PyObject *args)
{
  CvPOSITObject* posit_object;
  PyObject *pyobj_posit_object = NULL;
  CvPoint2D32f* image_points;
  PyObject *pyobj_image_points = NULL;
  double focal_length;
  CvTermCriteria criteria;
  PyObject *pyobj_criteria = NULL;
  CvMatr32f_i rotation_matrix;
  CvVect32f_i translation_vector;

  if (!PyArg_ParseTuple(args, "OOdO", &pyobj_posit_object, &pyobj_image_points, &focal_length, &pyobj_criteria))
    return NULL;
  if (!convert_to_CvPOSITObjectPTR(pyobj_posit_object, &posit_object, "posit_object")) return NULL;
  if (!convert_to_CvPoint2D32fPTR(pyobj_image_points, &image_points, "image_points")) return NULL;
  if (!convert_to_CvTermCriteria(pyobj_criteria, &criteria, "criteria")) return NULL;
  ERRWRAP(cvPOSIT(posit_object, image_points, focal_length, criteria, rotation_matrix, translation_vector));
  return Py_BuildValue("NN", FROM_CvMatr32f_i(rotation_matrix), FROM_CvVect32f_i(translation_vector));
}

static PyObject *pycvPerspectiveTransform(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvMat* mat;
  PyObject *pyobj_mat = NULL;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_src, &pyobj_dst, &pyobj_mat))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if (!convert_to_CvMat(pyobj_mat, &mat, "mat")) return NULL;
  ERRWRAP(cvPerspectiveTransform(src, dst, mat));
  Py_RETURN_NONE;
}

static PyObject *pycvPointPolygonTest(PyObject *self, PyObject *args)
{
  cvarrseq contour;
  PyObject *pyobj_contour = NULL;
  CvPoint2D32f pt;
  PyObject *pyobj_pt = NULL;
  int measure_dist;

  if (!PyArg_ParseTuple(args, "OOi", &pyobj_contour, &pyobj_pt, &measure_dist))
    return NULL;
  if (!convert_to_cvarrseq(pyobj_contour, &contour, "contour")) return NULL;
  if (!convert_to_CvPoint2D32f(pyobj_pt, &pt, "pt")) return NULL;
  double r;
  ERRWRAP(r = cvPointPolygonTest(contour.v, pt, measure_dist));
  return FROM_double(r);
}

static PyObject *pycvPolarToCart(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* magnitude;
  PyObject *pyobj_magnitude = NULL;
  CvArr* angle = NULL;
  PyObject *pyobj_angle = NULL;
  CvArr* x;
  PyObject *pyobj_x = NULL;
  CvArr* y;
  PyObject *pyobj_y = NULL;
  int angle_in_degrees;

  const char *keywords[] = { "magnitude", "angle", "x", "y", "angle_in_degrees", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOOi|O", (char**)keywords, &pyobj_magnitude, &pyobj_angle, &pyobj_x, &pyobj_y, &angle_in_degrees))
    return NULL;
  if (!convert_to_CvArr(pyobj_magnitude, &magnitude, "magnitude")) return NULL;
  if ((pyobj_angle != NULL) && !convert_to_CvArr(pyobj_angle, &angle, "angle")) return NULL;
  if (!convert_to_CvArr(pyobj_x, &x, "x")) return NULL;
  if (!convert_to_CvArr(pyobj_y, &y, "y")) return NULL;
  ERRWRAP(cvPolarToCart(magnitude, angle, x, y, angle_in_degrees));
  Py_RETURN_NONE;
}

static PyObject *pycvPolyLine(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* img;
  PyObject *pyobj_img = NULL;
  pts_npts_contours pts;
  PyObject *pyobj_pts = NULL;
  int is_closed;
  CvScalar color;
  PyObject *pyobj_color = NULL;
  int thickness = 1;
  int line_type = 8;
  int shift = 0;

  const char *keywords[] = { "img", "pts", "is_closed", "color", "thickness", "line_type", "shift", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOiO|iii", (char**)keywords, &pyobj_img, &pyobj_pts, &is_closed, &pyobj_color, &thickness, &line_type, &shift))
    return NULL;
  if (!convert_to_CvArr(pyobj_img, &img, "img")) return NULL;
  if (!convert_to_pts_npts_contours(pyobj_pts, &pts, "pts")) return NULL;
  if (!convert_to_CvScalar(pyobj_color, &color, "color")) return NULL;
  ERRWRAP(cvPolyLine(img, pts.pts,pts.npts,pts.contours, is_closed, color, thickness, line_type, shift));
  Py_RETURN_NONE;
}

static PyObject *pycvPow(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  double power;

  if (!PyArg_ParseTuple(args, "OOd", &pyobj_src, &pyobj_dst, &power))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvPow(src, dst, power));
  Py_RETURN_NONE;
}

static PyObject *pycvPreCornerDetect(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* image;
  PyObject *pyobj_image = NULL;
  CvArr* corners;
  PyObject *pyobj_corners = NULL;
  int aperture_size = 3;

  const char *keywords[] = { "image", "corners", "aperture_size", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|i", (char**)keywords, &pyobj_image, &pyobj_corners, &aperture_size))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvArr(pyobj_corners, &corners, "corners")) return NULL;
  ERRWRAP(cvPreCornerDetect(image, corners, aperture_size));
  Py_RETURN_NONE;
}

static PyObject *pycvProjectPCA(PyObject *self, PyObject *args)
{
  CvArr* data;
  PyObject *pyobj_data = NULL;
  CvArr* avg;
  PyObject *pyobj_avg = NULL;
  CvArr* eigenvectors;
  PyObject *pyobj_eigenvectors = NULL;
  CvArr* result;
  PyObject *pyobj_result = NULL;

  if (!PyArg_ParseTuple(args, "OOOO", &pyobj_data, &pyobj_avg, &pyobj_eigenvectors, &pyobj_result))
    return NULL;
  if (!convert_to_CvArr(pyobj_data, &data, "data")) return NULL;
  if (!convert_to_CvArr(pyobj_avg, &avg, "avg")) return NULL;
  if (!convert_to_CvArr(pyobj_eigenvectors, &eigenvectors, "eigenvectors")) return NULL;
  if (!convert_to_CvArr(pyobj_result, &result, "result")) return NULL;
  ERRWRAP(cvProjectPCA(data, avg, eigenvectors, result));
  Py_RETURN_NONE;
}

static PyObject *pycvProjectPoints2(PyObject *self, PyObject *args, PyObject *kw)
{
  CvMat* object_points;
  PyObject *pyobj_object_points = NULL;
  CvMat* rotation_vector;
  PyObject *pyobj_rotation_vector = NULL;
  CvMat* translation_vector;
  PyObject *pyobj_translation_vector = NULL;
  CvMat* intrinsic_matrix;
  PyObject *pyobj_intrinsic_matrix = NULL;
  CvMat* distortion_coeffs;
  PyObject *pyobj_distortion_coeffs = NULL;
  CvMat* image_points;
  PyObject *pyobj_image_points = NULL;
  CvMat* dpdrot = NULL;
  PyObject *pyobj_dpdrot = NULL;
  CvMat* dpdt = NULL;
  PyObject *pyobj_dpdt = NULL;
  CvMat* dpdf = NULL;
  PyObject *pyobj_dpdf = NULL;
  CvMat* dpdc = NULL;
  PyObject *pyobj_dpdc = NULL;
  CvMat* dpddist = NULL;
  PyObject *pyobj_dpddist = NULL;

  const char *keywords[] = { "object_points", "rotation_vector", "translation_vector", "intrinsic_matrix", "distortion_coeffs", "image_points", "dpdrot", "dpdt", "dpdf", "dpdc", "dpddist", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOOOOO|OOOOO", (char**)keywords, &pyobj_object_points, &pyobj_rotation_vector, &pyobj_translation_vector, &pyobj_intrinsic_matrix, &pyobj_distortion_coeffs, &pyobj_image_points, &pyobj_dpdrot, &pyobj_dpdt, &pyobj_dpdf, &pyobj_dpdc, &pyobj_dpddist))
    return NULL;
  if (!convert_to_CvMat(pyobj_object_points, &object_points, "object_points")) return NULL;
  if (!convert_to_CvMat(pyobj_rotation_vector, &rotation_vector, "rotation_vector")) return NULL;
  if (!convert_to_CvMat(pyobj_translation_vector, &translation_vector, "translation_vector")) return NULL;
  if (!convert_to_CvMat(pyobj_intrinsic_matrix, &intrinsic_matrix, "intrinsic_matrix")) return NULL;
  if (!convert_to_CvMat(pyobj_distortion_coeffs, &distortion_coeffs, "distortion_coeffs")) return NULL;
  if (!convert_to_CvMat(pyobj_image_points, &image_points, "image_points")) return NULL;
  if ((pyobj_dpdrot != NULL) && !convert_to_CvMat(pyobj_dpdrot, &dpdrot, "dpdrot")) return NULL;
  if ((pyobj_dpdt != NULL) && !convert_to_CvMat(pyobj_dpdt, &dpdt, "dpdt")) return NULL;
  if ((pyobj_dpdf != NULL) && !convert_to_CvMat(pyobj_dpdf, &dpdf, "dpdf")) return NULL;
  if ((pyobj_dpdc != NULL) && !convert_to_CvMat(pyobj_dpdc, &dpdc, "dpdc")) return NULL;
  if ((pyobj_dpddist != NULL) && !convert_to_CvMat(pyobj_dpddist, &dpddist, "dpddist")) return NULL;
  ERRWRAP(cvProjectPoints2(object_points, rotation_vector, translation_vector, intrinsic_matrix, distortion_coeffs, image_points, dpdrot, dpdt, dpdf, dpdc, dpddist));
  Py_RETURN_NONE;
}

static PyObject *pycvPutText(PyObject *self, PyObject *args)
{
  CvArr* img;
  PyObject *pyobj_img = NULL;
  char* text;
  CvPoint org;
  PyObject *pyobj_org = NULL;
  CvFont* font;
  PyObject *pyobj_font = NULL;
  CvScalar color;
  PyObject *pyobj_color = NULL;

  if (!PyArg_ParseTuple(args, "OsOOO", &pyobj_img, &text, &pyobj_org, &pyobj_font, &pyobj_color))
    return NULL;
  if (!convert_to_CvArr(pyobj_img, &img, "img")) return NULL;
  if (!convert_to_CvPoint(pyobj_org, &org, "org")) return NULL;
  if (!convert_to_CvFontPTR(pyobj_font, &font, "font")) return NULL;
  if (!convert_to_CvScalar(pyobj_color, &color, "color")) return NULL;
  ERRWRAP(cvPutText(img, text, org, font, color));
  Py_RETURN_NONE;
}

static PyObject *pycvPyrDown(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  int filter = CV_GAUSSIAN_5x5;

  const char *keywords[] = { "src", "dst", "filter", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|i", (char**)keywords, &pyobj_src, &pyobj_dst, &filter))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvPyrDown(src, dst, filter));
  Py_RETURN_NONE;
}

static PyObject *pycvPyrMeanShiftFiltering(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  double sp;
  double sr;
  int max_level = 1;
  CvTermCriteria termcrit = cvTermCriteria(CV_TERMCRIT_ITER+CV_TERMCRIT_EPS,5,1);
  PyObject *pyobj_termcrit = NULL;

  const char *keywords[] = { "src", "dst", "sp", "sr", "max_level", "termcrit", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOdd|iO", (char**)keywords, &pyobj_src, &pyobj_dst, &sp, &sr, &max_level, &pyobj_termcrit))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if ((pyobj_termcrit != NULL) && !convert_to_CvTermCriteria(pyobj_termcrit, &termcrit, "termcrit")) return NULL;
  ERRWRAP(cvPyrMeanShiftFiltering(src, dst, sp, sr, max_level, termcrit));
  Py_RETURN_NONE;
}

static PyObject *pycvPyrSegmentation(PyObject *self, PyObject *args)
{
  IplImage* src;
  PyObject *pyobj_src = NULL;
  IplImage* dst;
  PyObject *pyobj_dst = NULL;
  CvMemStorage* storage;
  PyObject *pyobj_storage = NULL;
  CvSeq* comp;
  int level;
  double threshold1;
  double threshold2;

  if (!PyArg_ParseTuple(args, "OOOidd", &pyobj_src, &pyobj_dst, &pyobj_storage, &level, &threshold1, &threshold2))
    return NULL;
  if (!convert_to_IplImage(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_IplImage(pyobj_dst, &dst, "dst")) return NULL;
  if (!convert_to_CvMemStorage(pyobj_storage, &storage, "storage")) return NULL;
  ERRWRAP(cvPyrSegmentation(src, dst, storage, &comp, level, threshold1, threshold2));
  return FROM_CvSeqPTR(comp);
}

static PyObject *pycvPyrUp(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  int filter = CV_GAUSSIAN_5x5;

  const char *keywords[] = { "src", "dst", "filter", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|i", (char**)keywords, &pyobj_src, &pyobj_dst, &filter))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvPyrUp(src, dst, filter));
  Py_RETURN_NONE;
}

static PyObject *pycvQueryFrame(PyObject *self, PyObject *args)
{
  CvCapture* capture;
  PyObject *pyobj_capture = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_capture))
    return NULL;
  if (!convert_to_CvCapturePTR(pyobj_capture, &capture, "capture")) return NULL;
  ROIplImage* r;
  ERRWRAP(r = cvQueryFrame(capture));
  return FROM_ROIplImagePTR(r);
}

static PyObject *pycvQueryHistValue_1D(PyObject *self, PyObject *args)
{
  CvHistogram* hist;
  PyObject *pyobj_hist = NULL;
  int idx0;

  if (!PyArg_ParseTuple(args, "Oi", &pyobj_hist, &idx0))
    return NULL;
  if (!convert_to_CvHistogram(pyobj_hist, &hist, "hist")) return NULL;
  double r;
  ERRWRAP(r = cvQueryHistValue_1D(hist, idx0));
  return FROM_double(r);
}

static PyObject *pycvQueryHistValue_2D(PyObject *self, PyObject *args)
{
  CvHistogram* hist;
  PyObject *pyobj_hist = NULL;
  int idx0;
  int idx1;

  if (!PyArg_ParseTuple(args, "Oii", &pyobj_hist, &idx0, &idx1))
    return NULL;
  if (!convert_to_CvHistogram(pyobj_hist, &hist, "hist")) return NULL;
  double r;
  ERRWRAP(r = cvQueryHistValue_2D(hist, idx0, idx1));
  return FROM_double(r);
}

static PyObject *pycvQueryHistValue_3D(PyObject *self, PyObject *args)
{
  CvHistogram* hist;
  PyObject *pyobj_hist = NULL;
  int idx0;
  int idx1;
  int idx2;

  if (!PyArg_ParseTuple(args, "Oiii", &pyobj_hist, &idx0, &idx1, &idx2))
    return NULL;
  if (!convert_to_CvHistogram(pyobj_hist, &hist, "hist")) return NULL;
  double r;
  ERRWRAP(r = cvQueryHistValue_3D(hist, idx0, idx1, idx2));
  return FROM_double(r);
}

static PyObject *pycvQueryHistValue_nD(PyObject *self, PyObject *args)
{
  CvHistogram* hist;
  PyObject *pyobj_hist = NULL;
  ints idx;
  PyObject *pyobj_idx = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_hist, &pyobj_idx))
    return NULL;
  if (!convert_to_CvHistogram(pyobj_hist, &hist, "hist")) return NULL;
  if (!convert_to_ints(pyobj_idx, &idx, "idx")) return NULL;
  double r;
  ERRWRAP(r = cvQueryHistValue_nD(hist, idx.i));
  return FROM_double(r);
}

static PyObject *pycvRNG(PyObject *self, PyObject *args, PyObject *kw)
{
  int64 seed = -1LL;

  const char *keywords[] = { "seed", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "|L", (char**)keywords, &seed))
    return NULL;
  CvRNG r;
  ERRWRAP(r = cvRNG(seed));
  return FROM_CvRNG(r);
}

static PyObject *pycvRandArr(PyObject *self, PyObject *args)
{
  CvRNG* rng;
  PyObject *pyobj_rng = NULL;
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  int dist_type;
  CvScalar param1;
  PyObject *pyobj_param1 = NULL;
  CvScalar param2;
  PyObject *pyobj_param2 = NULL;

  if (!PyArg_ParseTuple(args, "OOiOO", &pyobj_rng, &pyobj_arr, &dist_type, &pyobj_param1, &pyobj_param2))
    return NULL;
  if (!convert_to_CvRNGPTR(pyobj_rng, &rng, "rng")) return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  if (!convert_to_CvScalar(pyobj_param1, &param1, "param1")) return NULL;
  if (!convert_to_CvScalar(pyobj_param2, &param2, "param2")) return NULL;
  ERRWRAP(cvRandArr(rng, arr, dist_type, param1, param2));
  Py_RETURN_NONE;
}

static PyObject *pycvRandInt(PyObject *self, PyObject *args)
{
  CvRNG* rng;
  PyObject *pyobj_rng = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_rng))
    return NULL;
  if (!convert_to_CvRNGPTR(pyobj_rng, &rng, "rng")) return NULL;
  unsigned r;
  ERRWRAP(r = cvRandInt(rng));
  return FROM_unsigned(r);
}

static PyObject *pycvRandReal(PyObject *self, PyObject *args)
{
  CvRNG* rng;
  PyObject *pyobj_rng = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_rng))
    return NULL;
  if (!convert_to_CvRNGPTR(pyobj_rng, &rng, "rng")) return NULL;
  double r;
  ERRWRAP(r = cvRandReal(rng));
  return FROM_double(r);
}

static PyObject *pycvRandShuffle(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* mat;
  PyObject *pyobj_mat = NULL;
  CvRNG* rng;
  PyObject *pyobj_rng = NULL;
  double iter_factor = 1.0;

  const char *keywords[] = { "mat", "rng", "iter_factor", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|d", (char**)keywords, &pyobj_mat, &pyobj_rng, &iter_factor))
    return NULL;
  if (!convert_to_CvArr(pyobj_mat, &mat, "mat")) return NULL;
  if (!convert_to_CvRNGPTR(pyobj_rng, &rng, "rng")) return NULL;
  ERRWRAP(cvRandShuffle(mat, rng, iter_factor));
  Py_RETURN_NONE;
}

static PyObject *pycvRange(PyObject *self, PyObject *args)
{
  CvArr* mat;
  PyObject *pyobj_mat = NULL;
  double start;
  double end;

  if (!PyArg_ParseTuple(args, "Odd", &pyobj_mat, &start, &end))
    return NULL;
  if (!convert_to_CvArr(pyobj_mat, &mat, "mat")) return NULL;
  ERRWRAP(cvRange(mat, start, end));
  Py_RETURN_NONE;
}

static PyObject *pycvRealScalar(PyObject *self, PyObject *args)
{
  double val0;

  if (!PyArg_ParseTuple(args, "d", &val0))
    return NULL;
  CvScalar r;
  ERRWRAP(r = cvRealScalar(val0));
  return FROM_CvScalar(r);
}

static PyObject *pycvRectangle(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* img;
  PyObject *pyobj_img = NULL;
  CvPoint pt1;
  PyObject *pyobj_pt1 = NULL;
  CvPoint pt2;
  PyObject *pyobj_pt2 = NULL;
  CvScalar color;
  PyObject *pyobj_color = NULL;
  int thickness = 1;
  int line_type = 8;
  int shift = 0;

  const char *keywords[] = { "img", "pt1", "pt2", "color", "thickness", "line_type", "shift", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOOO|iii", (char**)keywords, &pyobj_img, &pyobj_pt1, &pyobj_pt2, &pyobj_color, &thickness, &line_type, &shift))
    return NULL;
  if (!convert_to_CvArr(pyobj_img, &img, "img")) return NULL;
  if (!convert_to_CvPoint(pyobj_pt1, &pt1, "pt1")) return NULL;
  if (!convert_to_CvPoint(pyobj_pt2, &pt2, "pt2")) return NULL;
  if (!convert_to_CvScalar(pyobj_color, &color, "color")) return NULL;
  ERRWRAP(cvRectangle(img, pt1, pt2, color, thickness, line_type, shift));
  Py_RETURN_NONE;
}

static PyObject *pycvReduce(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  int op = CV_REDUCE_SUM;

  const char *keywords[] = { "src", "dst", "op", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|i", (char**)keywords, &pyobj_src, &pyobj_dst, &op))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvReduce(src, dst, op));
  Py_RETURN_NONE;
}

static PyObject *pycvRemap(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvArr* mapx;
  PyObject *pyobj_mapx = NULL;
  CvArr* mapy;
  PyObject *pyobj_mapy = NULL;
  int flags = CV_INTER_LINEAR+CV_WARP_FILL_OUTLIERS;
  CvScalar fillval = cvScalarAll(0);
  PyObject *pyobj_fillval = NULL;

  const char *keywords[] = { "src", "dst", "mapx", "mapy", "flags", "fillval", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOOO|iO", (char**)keywords, &pyobj_src, &pyobj_dst, &pyobj_mapx, &pyobj_mapy, &flags, &pyobj_fillval))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if (!convert_to_CvArr(pyobj_mapx, &mapx, "mapx")) return NULL;
  if (!convert_to_CvArr(pyobj_mapy, &mapy, "mapy")) return NULL;
  if ((pyobj_fillval != NULL) && !convert_to_CvScalar(pyobj_fillval, &fillval, "fillval")) return NULL;
  ERRWRAP(cvRemap(src, dst, mapx, mapy, flags, fillval));
  Py_RETURN_NONE;
}

static PyObject *pycvRepeat(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_src, &pyobj_dst))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvRepeat(src, dst));
  Py_RETURN_NONE;
}

static PyObject *pycvResetImageROI(PyObject *self, PyObject *args)
{
  IplImage* image;
  PyObject *pyobj_image = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_image))
    return NULL;
  if (!convert_to_IplImage(pyobj_image, &image, "image")) return NULL;
  ERRWRAP(cvResetImageROI(image));
  Py_RETURN_NONE;
}

static PyObject *pycvResize(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  int interpolation = CV_INTER_LINEAR;

  const char *keywords[] = { "src", "dst", "interpolation", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|i", (char**)keywords, &pyobj_src, &pyobj_dst, &interpolation))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvResize(src, dst, interpolation));
  Py_RETURN_NONE;
}

static PyObject *pycvResizeWindow(PyObject *self, PyObject *args)
{
  char* name;
  int width;
  int height;

  if (!PyArg_ParseTuple(args, "sii", &name, &width, &height))
    return NULL;
  ERRWRAP(cvResizeWindow(name, width, height));
  Py_RETURN_NONE;
}

static PyObject *pycvRetrieveFrame(PyObject *self, PyObject *args)
{
  CvCapture* capture;
  PyObject *pyobj_capture = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_capture))
    return NULL;
  if (!convert_to_CvCapturePTR(pyobj_capture, &capture, "capture")) return NULL;
  ROIplImage* r;
  ERRWRAP(r = cvRetrieveFrame(capture));
  return FROM_ROIplImagePTR(r);
}

static PyObject *pycvRodrigues2(PyObject *self, PyObject *args, PyObject *kw)
{
  CvMat* src;
  PyObject *pyobj_src = NULL;
  CvMat* dst;
  PyObject *pyobj_dst = NULL;
  CvMat* jacobian = 0;
  PyObject *pyobj_jacobian = NULL;

  const char *keywords[] = { "src", "dst", "jacobian", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|O", (char**)keywords, &pyobj_src, &pyobj_dst, &pyobj_jacobian))
    return NULL;
  if (!convert_to_CvMat(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvMat(pyobj_dst, &dst, "dst")) return NULL;
  if ((pyobj_jacobian != NULL) && !convert_to_CvMat(pyobj_jacobian, &jacobian, "jacobian")) return NULL;
  ERRWRAP(cvRodrigues2(src, dst, jacobian));
  Py_RETURN_NONE;
}

static PyObject *pycvRound(PyObject *self, PyObject *args)
{
  double value;

  if (!PyArg_ParseTuple(args, "d", &value))
    return NULL;
  int r;
  ERRWRAP(r = cvRound(value));
  return FROM_int(r);
}

static PyObject *pycvRunningAvg(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* image;
  PyObject *pyobj_image = NULL;
  CvArr* acc;
  PyObject *pyobj_acc = NULL;
  double alpha;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "image", "acc", "alpha", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOd|O", (char**)keywords, &pyobj_image, &pyobj_acc, &alpha, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvArr(pyobj_acc, &acc, "acc")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvRunningAvg(image, acc, alpha, mask));
  Py_RETURN_NONE;
}

static PyObject *pycvSVBkSb(PyObject *self, PyObject *args)
{
  CvArr* W;
  PyObject *pyobj_W = NULL;
  CvArr* U;
  PyObject *pyobj_U = NULL;
  CvArr* V;
  PyObject *pyobj_V = NULL;
  CvArr* B;
  PyObject *pyobj_B = NULL;
  CvArr* X;
  PyObject *pyobj_X = NULL;
  int flags;

  if (!PyArg_ParseTuple(args, "OOOOOi", &pyobj_W, &pyobj_U, &pyobj_V, &pyobj_B, &pyobj_X, &flags))
    return NULL;
  if (!convert_to_CvArr(pyobj_W, &W, "W")) return NULL;
  if (!convert_to_CvArr(pyobj_U, &U, "U")) return NULL;
  if (!convert_to_CvArr(pyobj_V, &V, "V")) return NULL;
  if (!convert_to_CvArr(pyobj_B, &B, "B")) return NULL;
  if (!convert_to_CvArr(pyobj_X, &X, "X")) return NULL;
  ERRWRAP(cvSVBkSb(W, U, V, B, X, flags));
  Py_RETURN_NONE;
}

static PyObject *pycvSVD(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* A;
  PyObject *pyobj_A = NULL;
  CvArr* W;
  CvArr* U;
  CvArr* V;
  int flags = 0;

  const char *keywords[] = { "A", "flags", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "O|i", (char**)keywords, &pyobj_A, &flags))
    return NULL;
  if (!convert_to_CvArr(pyobj_A, &A, "A")) return NULL;
  ERRWRAP(cvSVD(A, &W, &U, &V, flags));
  Py_RETURN_NONE;
}

static PyObject *pycvSave(PyObject *self, PyObject *args, PyObject *kw)
{
  char* filename;
  generic struct_ptr;
  PyObject *pyobj_struct_ptr = NULL;
  char* name = NULL;
  char* comment = NULL;

  const char *keywords[] = { "filename", "struct_ptr", "name", "comment", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "sO|ss", (char**)keywords, &filename, &pyobj_struct_ptr, &name, &comment))
    return NULL;
  if (!convert_to_generic(pyobj_struct_ptr, &struct_ptr, "struct_ptr")) return NULL;
  ERRWRAP(cvSave(filename, struct_ptr, name, comment));
  Py_RETURN_NONE;
}

static PyObject *pycvSaveImage(PyObject *self, PyObject *args)
{
  char* filename;
  CvArr* image;
  PyObject *pyobj_image = NULL;

  if (!PyArg_ParseTuple(args, "sO", &filename, &pyobj_image))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  ERRWRAP(cvSaveImage(filename, image));
  Py_RETURN_NONE;
}

static PyObject *pycvScalar(PyObject *self, PyObject *args, PyObject *kw)
{
  double val0;
  double val1 = 0;
  double val2 = 0;
  double val3 = 0;

  const char *keywords[] = { "val0", "val1", "val2", "val3", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "d|ddd", (char**)keywords, &val0, &val1, &val2, &val3))
    return NULL;
  CvScalar r;
  ERRWRAP(r = cvScalar(val0, val1, val2, val3));
  return FROM_CvScalar(r);
}

static PyObject *pycvScalarAll(PyObject *self, PyObject *args)
{
  double val0123;

  if (!PyArg_ParseTuple(args, "d", &val0123))
    return NULL;
  CvScalar r;
  ERRWRAP(r = cvScalarAll(val0123));
  return FROM_CvScalar(r);
}

static PyObject *pycvScale(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  double scale = 1.0;
  double shift = 0.0;

  const char *keywords[] = { "src", "dst", "scale", "shift", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|dd", (char**)keywords, &pyobj_src, &pyobj_dst, &scale, &shift))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvScale(src, dst, scale, shift));
  Py_RETURN_NONE;
}

static PyObject *pycvScaleAdd(PyObject *self, PyObject *args)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvScalar scale;
  PyObject *pyobj_scale = NULL;
  CvArr* src2;
  PyObject *pyobj_src2 = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;

  if (!PyArg_ParseTuple(args, "OOOO", &pyobj_src1, &pyobj_scale, &pyobj_src2, &pyobj_dst))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvScalar(pyobj_scale, &scale, "scale")) return NULL;
  if (!convert_to_CvArr(pyobj_src2, &src2, "src2")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvScaleAdd(src1, scale, src2, dst));
  Py_RETURN_NONE;
}

static PyObject *pycvSegmentMotion(PyObject *self, PyObject *args)
{
  CvArr* mhi;
  PyObject *pyobj_mhi = NULL;
  CvArr* seg_mask;
  PyObject *pyobj_seg_mask = NULL;
  CvMemStorage* storage;
  PyObject *pyobj_storage = NULL;
  double timestamp;
  double seg_thresh;

  if (!PyArg_ParseTuple(args, "OOOdd", &pyobj_mhi, &pyobj_seg_mask, &pyobj_storage, &timestamp, &seg_thresh))
    return NULL;
  if (!convert_to_CvArr(pyobj_mhi, &mhi, "mhi")) return NULL;
  if (!convert_to_CvArr(pyobj_seg_mask, &seg_mask, "seg_mask")) return NULL;
  if (!convert_to_CvMemStorage(pyobj_storage, &storage, "storage")) return NULL;
  ERRWRAP(cvSegmentMotion(mhi, seg_mask, storage, timestamp, seg_thresh));
  Py_RETURN_NONE;
}

static PyObject *pycvSeqInvert(PyObject *self, PyObject *args)
{
  CvSeq* seq;
  PyObject *pyobj_seq = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_seq))
    return NULL;
  if (!convert_to_CvSeq(pyobj_seq, &seq, "seq")) return NULL;
  ERRWRAP(cvSeqInvert(seq));
  Py_RETURN_NONE;
}

static PyObject *pycvSeqRemove(PyObject *self, PyObject *args)
{
  CvSeq* seq;
  PyObject *pyobj_seq = NULL;
  int index;

  if (!PyArg_ParseTuple(args, "Oi", &pyobj_seq, &index))
    return NULL;
  if (!convert_to_CvSeq(pyobj_seq, &seq, "seq")) return NULL;
  ERRWRAP(cvSeqRemove(seq, index));
  Py_RETURN_NONE;
}

static PyObject *pycvSeqRemoveSlice(PyObject *self, PyObject *args)
{
  CvSeq* seq;
  PyObject *pyobj_seq = NULL;
  CvSlice slice;
  PyObject *pyobj_slice = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_seq, &pyobj_slice))
    return NULL;
  if (!convert_to_CvSeq(pyobj_seq, &seq, "seq")) return NULL;
  if (!convert_to_CvSlice(pyobj_slice, &slice, "slice")) return NULL;
  ERRWRAP(cvSeqRemoveSlice(seq, slice));
  Py_RETURN_NONE;
}

static PyObject *pycvSet(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  CvScalar value;
  PyObject *pyobj_value = NULL;
  CvArr* msk = NULL;
  PyObject *pyobj_msk = NULL;

  const char *keywords[] = { "arr", "value", "msk", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|O", (char**)keywords, &pyobj_arr, &pyobj_value, &pyobj_msk))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  if (!convert_to_CvScalar(pyobj_value, &value, "value")) return NULL;
  if ((pyobj_msk != NULL) && !convert_to_CvArr(pyobj_msk, &msk, "msk")) return NULL;
  ERRWRAP(cvSet(arr, value, msk));
  Py_RETURN_NONE;
}

static PyObject *pycvSet1D(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  int idx0;
  CvScalar value;
  PyObject *pyobj_value = NULL;

  if (!PyArg_ParseTuple(args, "OiO", &pyobj_arr, &idx0, &pyobj_value))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  if (!convert_to_CvScalar(pyobj_value, &value, "value")) return NULL;
  ERRWRAP(cvSet1D(arr, idx0, value));
  Py_RETURN_NONE;
}

static PyObject *pycvSet2D(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  int idx0;
  int idx1;
  CvScalar value;
  PyObject *pyobj_value = NULL;

  if (!PyArg_ParseTuple(args, "OiiO", &pyobj_arr, &idx0, &idx1, &pyobj_value))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  if (!convert_to_CvScalar(pyobj_value, &value, "value")) return NULL;
  ERRWRAP(cvSet2D(arr, idx0, idx1, value));
  Py_RETURN_NONE;
}

static PyObject *pycvSet3D(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  int idx0;
  int idx1;
  int idx2;
  CvScalar value;
  PyObject *pyobj_value = NULL;

  if (!PyArg_ParseTuple(args, "OiiiO", &pyobj_arr, &idx0, &idx1, &idx2, &pyobj_value))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  if (!convert_to_CvScalar(pyobj_value, &value, "value")) return NULL;
  ERRWRAP(cvSet3D(arr, idx0, idx1, idx2, value));
  Py_RETURN_NONE;
}

static PyObject *pycvSetCaptureProperty(PyObject *self, PyObject *args)
{
  CvCapture* capture;
  PyObject *pyobj_capture = NULL;
  int property_id;
  double value;

  if (!PyArg_ParseTuple(args, "Oid", &pyobj_capture, &property_id, &value))
    return NULL;
  if (!convert_to_CvCapturePTR(pyobj_capture, &capture, "capture")) return NULL;
  int r;
  ERRWRAP(r = cvSetCaptureProperty(capture, property_id, value));
  return FROM_int(r);
}

static PyObject *pycvSetIdentity(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* mat;
  PyObject *pyobj_mat = NULL;
  CvScalar value = cvRealScalar(1);
  PyObject *pyobj_value = NULL;

  const char *keywords[] = { "mat", "value", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "O|O", (char**)keywords, &pyobj_mat, &pyobj_value))
    return NULL;
  if (!convert_to_CvArr(pyobj_mat, &mat, "mat")) return NULL;
  if ((pyobj_value != NULL) && !convert_to_CvScalar(pyobj_value, &value, "value")) return NULL;
  ERRWRAP(cvSetIdentity(mat, value));
  Py_RETURN_NONE;
}

static PyObject *pycvSetImageCOI(PyObject *self, PyObject *args)
{
  IplImage* image;
  PyObject *pyobj_image = NULL;
  int coi;

  if (!PyArg_ParseTuple(args, "Oi", &pyobj_image, &coi))
    return NULL;
  if (!convert_to_IplImage(pyobj_image, &image, "image")) return NULL;
  ERRWRAP(cvSetImageCOI(image, coi));
  Py_RETURN_NONE;
}

static PyObject *pycvSetImageROI(PyObject *self, PyObject *args)
{
  IplImage* image;
  PyObject *pyobj_image = NULL;
  CvRect rect;
  PyObject *pyobj_rect = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_image, &pyobj_rect))
    return NULL;
  if (!convert_to_IplImage(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvRect(pyobj_rect, &rect, "rect")) return NULL;
  ERRWRAP(cvSetImageROI(image, rect));
  Py_RETURN_NONE;
}

static PyObject *pycvSetND(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  ints idx;
  PyObject *pyobj_idx = NULL;
  CvScalar value;
  PyObject *pyobj_value = NULL;

  if (!PyArg_ParseTuple(args, "OOO", &pyobj_arr, &pyobj_idx, &pyobj_value))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  if (!convert_to_ints(pyobj_idx, &idx, "idx")) return NULL;
  if (!convert_to_CvScalar(pyobj_value, &value, "value")) return NULL;
  ERRWRAP(cvSetND(arr, idx.i, value));
  Py_RETURN_NONE;
}

static PyObject *pycvSetReal1D(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  int idx0;
  double value;

  if (!PyArg_ParseTuple(args, "Oid", &pyobj_arr, &idx0, &value))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  ERRWRAP(cvSetReal1D(arr, idx0, value));
  Py_RETURN_NONE;
}

static PyObject *pycvSetReal2D(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  int idx0;
  int idx1;
  double value;

  if (!PyArg_ParseTuple(args, "Oiid", &pyobj_arr, &idx0, &idx1, &value))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  ERRWRAP(cvSetReal2D(arr, idx0, idx1, value));
  Py_RETURN_NONE;
}

static PyObject *pycvSetReal3D(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  int idx0;
  int idx1;
  int idx2;
  double value;

  if (!PyArg_ParseTuple(args, "Oiiid", &pyobj_arr, &idx0, &idx1, &idx2, &value))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  ERRWRAP(cvSetReal3D(arr, idx0, idx1, idx2, value));
  Py_RETURN_NONE;
}

static PyObject *pycvSetRealND(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;
  ints idx;
  PyObject *pyobj_idx = NULL;
  double value;

  if (!PyArg_ParseTuple(args, "OOd", &pyobj_arr, &pyobj_idx, &value))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  if (!convert_to_ints(pyobj_idx, &idx, "idx")) return NULL;
  ERRWRAP(cvSetRealND(arr, idx.i, value));
  Py_RETURN_NONE;
}

static PyObject *pycvSetTrackbarPos(PyObject *self, PyObject *args)
{
  char* trackbar_name;
  char* window_name;
  int pos;

  if (!PyArg_ParseTuple(args, "ssi", &trackbar_name, &window_name, &pos))
    return NULL;
  ERRWRAP(cvSetTrackbarPos(trackbar_name, window_name, pos));
  Py_RETURN_NONE;
}

static PyObject *pycvSetZero(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_arr))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  ERRWRAP(cvSetZero(arr));
  Py_RETURN_NONE;
}

static PyObject *pycvShowImage(PyObject *self, PyObject *args)
{
  char* name;
  CvArr* image;
  PyObject *pyobj_image = NULL;

  if (!PyArg_ParseTuple(args, "sO", &name, &pyobj_image))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  ERRWRAP(cvShowImage(name, image));
  Py_RETURN_NONE;
}

static PyObject *pycvSmooth(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  int smoothtype = CV_GAUSSIAN;
  int param1 = 3;
  int param2 = 0;
  double param3 = 0;
  double param4 = 0;

  const char *keywords[] = { "src", "dst", "smoothtype", "param1", "param2", "param3", "param4", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|iiidd", (char**)keywords, &pyobj_src, &pyobj_dst, &smoothtype, &param1, &param2, &param3, &param4))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvSmooth(src, dst, smoothtype, param1, param2, param3, param4));
  Py_RETURN_NONE;
}

static PyObject *pycvSnakeImage(PyObject *self, PyObject *args, PyObject *kw)
{
  IplImage* image;
  PyObject *pyobj_image = NULL;
  CvPoints points;
  PyObject *pyobj_points = NULL;
  floats alpha;
  PyObject *pyobj_alpha = NULL;
  floats beta;
  PyObject *pyobj_beta = NULL;
  floats gamma;
  PyObject *pyobj_gamma = NULL;
  int coeff_usage;
  CvSize win;
  PyObject *pyobj_win = NULL;
  CvTermCriteria criteria;
  PyObject *pyobj_criteria = NULL;
  int calc_gradient = 1;

  const char *keywords[] = { "image", "points", "alpha", "beta", "gamma", "coeff_usage", "win", "criteria", "calc_gradient", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOOOOiOO|i", (char**)keywords, &pyobj_image, &pyobj_points, &pyobj_alpha, &pyobj_beta, &pyobj_gamma, &coeff_usage, &pyobj_win, &pyobj_criteria, &calc_gradient))
    return NULL;
  if (!convert_to_IplImage(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvPoints(pyobj_points, &points, "points")) return NULL;
  if (!convert_to_floats(pyobj_alpha, &alpha, "alpha")) return NULL;
  if (!convert_to_floats(pyobj_beta, &beta, "beta")) return NULL;
  if (!convert_to_floats(pyobj_gamma, &gamma, "gamma")) return NULL;
  if (!convert_to_CvSize(pyobj_win, &win, "win")) return NULL;
  if (!convert_to_CvTermCriteria(pyobj_criteria, &criteria, "criteria")) return NULL;
  ERRWRAP(cvSnakeImage(image, points.p,points.count, alpha.f, beta.f, gamma.f, coeff_usage, win, criteria, calc_gradient));
  Py_RETURN_NONE;
}

static PyObject *pycvSobel(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  int xorder;
  int yorder;
  int aperture_size = 3;

  const char *keywords[] = { "src", "dst", "xorder", "yorder", "aperture_size", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOii|i", (char**)keywords, &pyobj_src, &pyobj_dst, &xorder, &yorder, &aperture_size))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvSobel(src, dst, xorder, yorder, aperture_size));
  Py_RETURN_NONE;
}

static PyObject *pycvSolve(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* A;
  PyObject *pyobj_A = NULL;
  CvArr* B;
  PyObject *pyobj_B = NULL;
  CvArr* X;
  PyObject *pyobj_X = NULL;
  int method = CV_LU;

  const char *keywords[] = { "A", "B", "X", "method", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|i", (char**)keywords, &pyobj_A, &pyobj_B, &pyobj_X, &method))
    return NULL;
  if (!convert_to_CvArr(pyobj_A, &A, "A")) return NULL;
  if (!convert_to_CvArr(pyobj_B, &B, "B")) return NULL;
  if (!convert_to_CvArr(pyobj_X, &X, "X")) return NULL;
  ERRWRAP(cvSolve(A, B, X, method));
  Py_RETURN_NONE;
}

static PyObject *pycvSolveCubic(PyObject *self, PyObject *args)
{
  CvMat* coeffs;
  PyObject *pyobj_coeffs = NULL;
  CvMat* roots;
  PyObject *pyobj_roots = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_coeffs, &pyobj_roots))
    return NULL;
  if (!convert_to_CvMat(pyobj_coeffs, &coeffs, "coeffs")) return NULL;
  if (!convert_to_CvMat(pyobj_roots, &roots, "roots")) return NULL;
  ERRWRAP(cvSolveCubic(coeffs, roots));
  Py_RETURN_NONE;
}

static PyObject *pycvSolvePoly(PyObject *self, PyObject *args, PyObject *kw)
{
  CvMat* coeffs;
  PyObject *pyobj_coeffs = NULL;
  CvMat* roots;
  PyObject *pyobj_roots = NULL;
  int maxiter = 10;
  int fig = 10;

  const char *keywords[] = { "coeffs", "roots", "maxiter", "fig", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|ii", (char**)keywords, &pyobj_coeffs, &pyobj_roots, &maxiter, &fig))
    return NULL;
  if (!convert_to_CvMat(pyobj_coeffs, &coeffs, "coeffs")) return NULL;
  if (!convert_to_CvMat(pyobj_roots, &roots, "roots")) return NULL;
  ERRWRAP(cvSolvePoly(coeffs, roots, maxiter, fig));
  Py_RETURN_NONE;
}

static PyObject *pycvSort(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvArr* idxmat;
  PyObject *pyobj_idxmat = NULL;
  int flags = 0;

  const char *keywords[] = { "src", "dst", "idxmat", "flags", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|i", (char**)keywords, &pyobj_src, &pyobj_dst, &pyobj_idxmat, &flags))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if (!convert_to_CvArr(pyobj_idxmat, &idxmat, "idxmat")) return NULL;
  ERRWRAP(cvSort(src, dst, idxmat, flags));
  Py_RETURN_NONE;
}

static PyObject *pycvSplit(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst0;
  PyObject *pyobj_dst0 = NULL;
  CvArr* dst1;
  PyObject *pyobj_dst1 = NULL;
  CvArr* dst2;
  PyObject *pyobj_dst2 = NULL;
  CvArr* dst3;
  PyObject *pyobj_dst3 = NULL;

  if (!PyArg_ParseTuple(args, "OOOOO", &pyobj_src, &pyobj_dst0, &pyobj_dst1, &pyobj_dst2, &pyobj_dst3))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst0, &dst0, "dst0")) return NULL;
  if (!convert_to_CvArr(pyobj_dst1, &dst1, "dst1")) return NULL;
  if (!convert_to_CvArr(pyobj_dst2, &dst2, "dst2")) return NULL;
  if (!convert_to_CvArr(pyobj_dst3, &dst3, "dst3")) return NULL;
  ERRWRAP(cvSplit(src, dst0, dst1, dst2, dst3));
  Py_RETURN_NONE;
}

static PyObject *pycvSqrt(PyObject *self, PyObject *args)
{
  float value;

  if (!PyArg_ParseTuple(args, "f", &value))
    return NULL;
  float r;
  ERRWRAP(r = cvSqrt(value));
  return FROM_float(r);
}

static PyObject *pycvSquareAcc(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* image;
  PyObject *pyobj_image = NULL;
  CvArr* sqsum;
  PyObject *pyobj_sqsum = NULL;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "image", "sqsum", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OO|O", (char**)keywords, &pyobj_image, &pyobj_sqsum, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvArr(pyobj_sqsum, &sqsum, "sqsum")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvSquareAcc(image, sqsum, mask));
  Py_RETURN_NONE;
}

static PyObject *pycvStereoCalibrate(PyObject *self, PyObject *args, PyObject *kw)
{
  CvMat* object_points;
  PyObject *pyobj_object_points = NULL;
  CvMat* image_points1;
  PyObject *pyobj_image_points1 = NULL;
  CvMat* image_points2;
  PyObject *pyobj_image_points2 = NULL;
  CvMat* point_counts;
  PyObject *pyobj_point_counts = NULL;
  CvMat* camera_matrix1;
  PyObject *pyobj_camera_matrix1 = NULL;
  CvMat* dist_coeffs1;
  PyObject *pyobj_dist_coeffs1 = NULL;
  CvMat* camera_matrix2;
  PyObject *pyobj_camera_matrix2 = NULL;
  CvMat* dist_coeffs2;
  PyObject *pyobj_dist_coeffs2 = NULL;
  CvSize image_size;
  PyObject *pyobj_image_size = NULL;
  CvMat* R;
  PyObject *pyobj_R = NULL;
  CvMat* T;
  PyObject *pyobj_T = NULL;
  CvMat* E = NULL;
  PyObject *pyobj_E = NULL;
  CvMat* F = NULL;
  PyObject *pyobj_F = NULL;
  CvTermCriteria term_crit = cvTermCriteria(CV_TERMCRIT_ITER+CV_TERMCRIT_EPS,30,1e-6);
  PyObject *pyobj_term_crit = NULL;
  int flags = CV_CALIB_FIX_INTRINSIC;

  const char *keywords[] = { "object_points", "image_points1", "image_points2", "point_counts", "camera_matrix1", "dist_coeffs1", "camera_matrix2", "dist_coeffs2", "image_size", "R", "T", "E", "F", "term_crit", "flags", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOOOOOOOOOO|OOOi", (char**)keywords, &pyobj_object_points, &pyobj_image_points1, &pyobj_image_points2, &pyobj_point_counts, &pyobj_camera_matrix1, &pyobj_dist_coeffs1, &pyobj_camera_matrix2, &pyobj_dist_coeffs2, &pyobj_image_size, &pyobj_R, &pyobj_T, &pyobj_E, &pyobj_F, &pyobj_term_crit, &flags))
    return NULL;
  if (!convert_to_CvMat(pyobj_object_points, &object_points, "object_points")) return NULL;
  if (!convert_to_CvMat(pyobj_image_points1, &image_points1, "image_points1")) return NULL;
  if (!convert_to_CvMat(pyobj_image_points2, &image_points2, "image_points2")) return NULL;
  if (!convert_to_CvMat(pyobj_point_counts, &point_counts, "point_counts")) return NULL;
  if (!convert_to_CvMat(pyobj_camera_matrix1, &camera_matrix1, "camera_matrix1")) return NULL;
  if (!convert_to_CvMat(pyobj_dist_coeffs1, &dist_coeffs1, "dist_coeffs1")) return NULL;
  if (!convert_to_CvMat(pyobj_camera_matrix2, &camera_matrix2, "camera_matrix2")) return NULL;
  if (!convert_to_CvMat(pyobj_dist_coeffs2, &dist_coeffs2, "dist_coeffs2")) return NULL;
  if (!convert_to_CvSize(pyobj_image_size, &image_size, "image_size")) return NULL;
  if (!convert_to_CvMat(pyobj_R, &R, "R")) return NULL;
  if (!convert_to_CvMat(pyobj_T, &T, "T")) return NULL;
  if ((pyobj_E != NULL) && !convert_to_CvMat(pyobj_E, &E, "E")) return NULL;
  if ((pyobj_F != NULL) && !convert_to_CvMat(pyobj_F, &F, "F")) return NULL;
  if ((pyobj_term_crit != NULL) && !convert_to_CvTermCriteria(pyobj_term_crit, &term_crit, "term_crit")) return NULL;
  ERRWRAP(cvStereoCalibrate(object_points, image_points1, image_points2, point_counts, camera_matrix1, dist_coeffs1, camera_matrix2, dist_coeffs2, image_size, R, T, E, F, term_crit, flags));
  Py_RETURN_NONE;
}

static PyObject *pycvStereoRectify(PyObject *self, PyObject *args, PyObject *kw)
{
  CvMat* camera_matrix1;
  PyObject *pyobj_camera_matrix1 = NULL;
  CvMat* camera_matrix2;
  PyObject *pyobj_camera_matrix2 = NULL;
  CvMat* dist_coeffs1;
  PyObject *pyobj_dist_coeffs1 = NULL;
  CvMat* dist_coeffs2;
  PyObject *pyobj_dist_coeffs2 = NULL;
  CvSize image_size;
  PyObject *pyobj_image_size = NULL;
  CvMat* R;
  PyObject *pyobj_R = NULL;
  CvMat* T;
  PyObject *pyobj_T = NULL;
  CvMat* R1;
  PyObject *pyobj_R1 = NULL;
  CvMat* R2;
  PyObject *pyobj_R2 = NULL;
  CvMat* P1;
  PyObject *pyobj_P1 = NULL;
  CvMat* P2;
  PyObject *pyobj_P2 = NULL;
  CvMat* Q = NULL;
  PyObject *pyobj_Q = NULL;
  int flags = CV_CALIB_ZERO_DISPARITY;

  const char *keywords[] = { "camera_matrix1", "camera_matrix2", "dist_coeffs1", "dist_coeffs2", "image_size", "R", "T", "R1", "R2", "P1", "P2", "Q", "flags", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOOOOOOOOOO|Oi", (char**)keywords, &pyobj_camera_matrix1, &pyobj_camera_matrix2, &pyobj_dist_coeffs1, &pyobj_dist_coeffs2, &pyobj_image_size, &pyobj_R, &pyobj_T, &pyobj_R1, &pyobj_R2, &pyobj_P1, &pyobj_P2, &pyobj_Q, &flags))
    return NULL;
  if (!convert_to_CvMat(pyobj_camera_matrix1, &camera_matrix1, "camera_matrix1")) return NULL;
  if (!convert_to_CvMat(pyobj_camera_matrix2, &camera_matrix2, "camera_matrix2")) return NULL;
  if (!convert_to_CvMat(pyobj_dist_coeffs1, &dist_coeffs1, "dist_coeffs1")) return NULL;
  if (!convert_to_CvMat(pyobj_dist_coeffs2, &dist_coeffs2, "dist_coeffs2")) return NULL;
  if (!convert_to_CvSize(pyobj_image_size, &image_size, "image_size")) return NULL;
  if (!convert_to_CvMat(pyobj_R, &R, "R")) return NULL;
  if (!convert_to_CvMat(pyobj_T, &T, "T")) return NULL;
  if (!convert_to_CvMat(pyobj_R1, &R1, "R1")) return NULL;
  if (!convert_to_CvMat(pyobj_R2, &R2, "R2")) return NULL;
  if (!convert_to_CvMat(pyobj_P1, &P1, "P1")) return NULL;
  if (!convert_to_CvMat(pyobj_P2, &P2, "P2")) return NULL;
  if ((pyobj_Q != NULL) && !convert_to_CvMat(pyobj_Q, &Q, "Q")) return NULL;
  ERRWRAP(cvStereoRectify(camera_matrix1, camera_matrix2, dist_coeffs1, dist_coeffs2, image_size, R, T, R1, R2, P1, P2, Q, flags));
  Py_RETURN_NONE;
}

static PyObject *pycvStereoRectifyUncalibrated(PyObject *self, PyObject *args, PyObject *kw)
{
  CvMat* points1;
  PyObject *pyobj_points1 = NULL;
  CvMat* points2;
  PyObject *pyobj_points2 = NULL;
  CvMat* F;
  PyObject *pyobj_F = NULL;
  CvSize image_size;
  PyObject *pyobj_image_size = NULL;
  CvMat* H1;
  PyObject *pyobj_H1 = NULL;
  CvMat* H2;
  PyObject *pyobj_H2 = NULL;
  double threshold = 5;

  const char *keywords[] = { "points1", "points2", "F", "image_size", "H1", "H2", "threshold", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOOOOO|d", (char**)keywords, &pyobj_points1, &pyobj_points2, &pyobj_F, &pyobj_image_size, &pyobj_H1, &pyobj_H2, &threshold))
    return NULL;
  if (!convert_to_CvMat(pyobj_points1, &points1, "points1")) return NULL;
  if (!convert_to_CvMat(pyobj_points2, &points2, "points2")) return NULL;
  if (!convert_to_CvMat(pyobj_F, &F, "F")) return NULL;
  if (!convert_to_CvSize(pyobj_image_size, &image_size, "image_size")) return NULL;
  if (!convert_to_CvMat(pyobj_H1, &H1, "H1")) return NULL;
  if (!convert_to_CvMat(pyobj_H2, &H2, "H2")) return NULL;
  ERRWRAP(cvStereoRectifyUncalibrated(points1, points2, F, image_size, H1, H2, threshold));
  Py_RETURN_NONE;
}

static PyObject *pycvSub(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvArr* src2;
  PyObject *pyobj_src2 = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "src1", "src2", "dst", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|O", (char**)keywords, &pyobj_src1, &pyobj_src2, &pyobj_dst, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvArr(pyobj_src2, &src2, "src2")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvSub(src1, src2, dst, mask));
  Py_RETURN_NONE;
}

static PyObject *pycvSubRS(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvScalar value;
  PyObject *pyobj_value = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "src1", "value", "dst", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|O", (char**)keywords, &pyobj_src1, &pyobj_value, &pyobj_dst, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvScalar(pyobj_value, &value, "value")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvSubRS(src1, value, dst, mask));
  Py_RETURN_NONE;
}

static PyObject *pycvSubS(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvScalar value;
  PyObject *pyobj_value = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "src1", "value", "dst", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|O", (char**)keywords, &pyobj_src1, &pyobj_value, &pyobj_dst, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvScalar(pyobj_value, &value, "value")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvSubS(src1, value, dst, mask));
  Py_RETURN_NONE;
}

static PyObject *pycvSubdiv2DEdgeDst(PyObject *self, PyObject *args)
{
  CvSubdiv2DEdge edge;
  PyObject *pyobj_edge = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_edge))
    return NULL;
  if (!convert_to_CvSubdiv2DEdge(pyobj_edge, &edge, "edge")) return NULL;
  CvSubdiv2DPoint* r;
  ERRWRAP(r = cvSubdiv2DEdgeDst(edge));
  return FROM_CvSubdiv2DPointPTR(r);
}

static PyObject *pycvSubdiv2DEdgeOrg(PyObject *self, PyObject *args)
{
  CvSubdiv2DEdge edge;
  PyObject *pyobj_edge = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_edge))
    return NULL;
  if (!convert_to_CvSubdiv2DEdge(pyobj_edge, &edge, "edge")) return NULL;
  CvSubdiv2DPoint* r;
  ERRWRAP(r = cvSubdiv2DEdgeOrg(edge));
  return FROM_CvSubdiv2DPointPTR(r);
}

static PyObject *pycvSubdiv2DGetEdge(PyObject *self, PyObject *args)
{
  CvSubdiv2DEdge edge;
  PyObject *pyobj_edge = NULL;
  CvNextEdgeType type;
  PyObject *pyobj_type = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_edge, &pyobj_type))
    return NULL;
  if (!convert_to_CvSubdiv2DEdge(pyobj_edge, &edge, "edge")) return NULL;
  if (!convert_to_CvNextEdgeType(pyobj_type, &type, "type")) return NULL;
  CvSubdiv2DEdge r;
  ERRWRAP(r = cvSubdiv2DGetEdge(edge, type));
  return FROM_CvSubdiv2DEdge(r);
}

static PyObject *pycvSubdiv2DNextEdge(PyObject *self, PyObject *args)
{
  CvSubdiv2DEdge edge;
  PyObject *pyobj_edge = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_edge))
    return NULL;
  if (!convert_to_CvSubdiv2DEdge(pyobj_edge, &edge, "edge")) return NULL;
  CvSubdiv2DEdge r;
  ERRWRAP(r = cvSubdiv2DNextEdge(edge));
  return FROM_CvSubdiv2DEdge(r);
}

static PyObject *pycvSubdiv2DRotateEdge(PyObject *self, PyObject *args)
{
  CvSubdiv2DEdge edge;
  PyObject *pyobj_edge = NULL;
  int rotate;

  if (!PyArg_ParseTuple(args, "Oi", &pyobj_edge, &rotate))
    return NULL;
  if (!convert_to_CvSubdiv2DEdge(pyobj_edge, &edge, "edge")) return NULL;
  CvSubdiv2DEdge r;
  ERRWRAP(r = cvSubdiv2DRotateEdge(edge, rotate));
  return FROM_CvSubdiv2DEdge(r);
}

static PyObject *pycvSubdivDelaunay2DInsert(PyObject *self, PyObject *args)
{
  CvSubdiv2D* subdiv;
  PyObject *pyobj_subdiv = NULL;
  CvPoint2D32f pt;
  PyObject *pyobj_pt = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_subdiv, &pyobj_pt))
    return NULL;
  if (!convert_to_CvSubdiv2DPTR(pyobj_subdiv, &subdiv, "subdiv")) return NULL;
  if (!convert_to_CvPoint2D32f(pyobj_pt, &pt, "pt")) return NULL;
  CvSubdiv2DPoint* r;
  ERRWRAP(r = cvSubdivDelaunay2DInsert(subdiv, pt));
  return FROM_CvSubdiv2DPointPTR(r);
}

static PyObject *pycvSum(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_arr))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  CvScalar r;
  ERRWRAP(r = cvSum(arr));
  return FROM_CvScalar(r);
}

static PyObject *pycvThreshHist(PyObject *self, PyObject *args)
{
  CvHistogram* hist;
  PyObject *pyobj_hist = NULL;
  double threshold;

  if (!PyArg_ParseTuple(args, "Od", &pyobj_hist, &threshold))
    return NULL;
  if (!convert_to_CvHistogram(pyobj_hist, &hist, "hist")) return NULL;
  ERRWRAP(cvThreshHist(hist, threshold));
  Py_RETURN_NONE;
}

static PyObject *pycvThreshold(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  double threshold;
  double max_value;
  int threshold_type;

  if (!PyArg_ParseTuple(args, "OOddi", &pyobj_src, &pyobj_dst, &threshold, &max_value, &threshold_type))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvThreshold(src, dst, threshold, max_value, threshold_type));
  Py_RETURN_NONE;
}

static PyObject *pycvTrace(PyObject *self, PyObject *args)
{
  CvArr* mat;
  PyObject *pyobj_mat = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_mat))
    return NULL;
  if (!convert_to_CvArr(pyobj_mat, &mat, "mat")) return NULL;
  CvScalar r;
  ERRWRAP(r = cvTrace(mat));
  return FROM_CvScalar(r);
}

static PyObject *pycvTransform(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvMat* transmat;
  PyObject *pyobj_transmat = NULL;
  CvMat* shiftvec = NULL;
  PyObject *pyobj_shiftvec = NULL;

  const char *keywords[] = { "src", "dst", "transmat", "shiftvec", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|O", (char**)keywords, &pyobj_src, &pyobj_dst, &pyobj_transmat, &pyobj_shiftvec))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if (!convert_to_CvMat(pyobj_transmat, &transmat, "transmat")) return NULL;
  if ((pyobj_shiftvec != NULL) && !convert_to_CvMat(pyobj_shiftvec, &shiftvec, "shiftvec")) return NULL;
  ERRWRAP(cvTransform(src, dst, transmat, shiftvec));
  Py_RETURN_NONE;
}

static PyObject *pycvTranspose(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_src, &pyobj_dst))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  ERRWRAP(cvTranspose(src, dst));
  Py_RETURN_NONE;
}

static PyObject *pycvUndistort2(PyObject *self, PyObject *args)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvMat* intrinsic_matrix;
  PyObject *pyobj_intrinsic_matrix = NULL;
  CvMat* distortion_coeffs;
  PyObject *pyobj_distortion_coeffs = NULL;

  if (!PyArg_ParseTuple(args, "OOOO", &pyobj_src, &pyobj_dst, &pyobj_intrinsic_matrix, &pyobj_distortion_coeffs))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if (!convert_to_CvMat(pyobj_intrinsic_matrix, &intrinsic_matrix, "intrinsic_matrix")) return NULL;
  if (!convert_to_CvMat(pyobj_distortion_coeffs, &distortion_coeffs, "distortion_coeffs")) return NULL;
  ERRWRAP(cvUndistort2(src, dst, intrinsic_matrix, distortion_coeffs));
  Py_RETURN_NONE;
}

static PyObject *pycvUndistortPoints(PyObject *self, PyObject *args, PyObject *kw)
{
  CvMat* src;
  PyObject *pyobj_src = NULL;
  CvMat* dst;
  PyObject *pyobj_dst = NULL;
  CvMat* camera_matrix;
  PyObject *pyobj_camera_matrix = NULL;
  CvMat* dist_coeffs;
  PyObject *pyobj_dist_coeffs = NULL;
  CvMat* R = NULL;
  PyObject *pyobj_R = NULL;
  CvMat* P = NULL;
  PyObject *pyobj_P = NULL;

  const char *keywords[] = { "src", "dst", "camera_matrix", "dist_coeffs", "R", "P", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOOO|OO", (char**)keywords, &pyobj_src, &pyobj_dst, &pyobj_camera_matrix, &pyobj_dist_coeffs, &pyobj_R, &pyobj_P))
    return NULL;
  if (!convert_to_CvMat(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvMat(pyobj_dst, &dst, "dst")) return NULL;
  if (!convert_to_CvMat(pyobj_camera_matrix, &camera_matrix, "camera_matrix")) return NULL;
  if (!convert_to_CvMat(pyobj_dist_coeffs, &dist_coeffs, "dist_coeffs")) return NULL;
  if ((pyobj_R != NULL) && !convert_to_CvMat(pyobj_R, &R, "R")) return NULL;
  if ((pyobj_P != NULL) && !convert_to_CvMat(pyobj_P, &P, "P")) return NULL;
  ERRWRAP(cvUndistortPoints(src, dst, camera_matrix, dist_coeffs, R, P));
  Py_RETURN_NONE;
}

static PyObject *pycvUpdateMotionHistory(PyObject *self, PyObject *args)
{
  CvArr* silhouette;
  PyObject *pyobj_silhouette = NULL;
  CvArr* mhi;
  PyObject *pyobj_mhi = NULL;
  double timestamp;
  double duration;

  if (!PyArg_ParseTuple(args, "OOdd", &pyobj_silhouette, &pyobj_mhi, &timestamp, &duration))
    return NULL;
  if (!convert_to_CvArr(pyobj_silhouette, &silhouette, "silhouette")) return NULL;
  if (!convert_to_CvArr(pyobj_mhi, &mhi, "mhi")) return NULL;
  ERRWRAP(cvUpdateMotionHistory(silhouette, mhi, timestamp, duration));
  Py_RETURN_NONE;
}

static PyObject *pycvWarpAffine(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvMat* map_matrix;
  PyObject *pyobj_map_matrix = NULL;
  int flags = CV_INTER_LINEAR+CV_WARP_FILL_OUTLIERS;
  CvScalar fillval = cvScalarAll(0);
  PyObject *pyobj_fillval = NULL;

  const char *keywords[] = { "src", "dst", "map_matrix", "flags", "fillval", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|iO", (char**)keywords, &pyobj_src, &pyobj_dst, &pyobj_map_matrix, &flags, &pyobj_fillval))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if (!convert_to_CvMat(pyobj_map_matrix, &map_matrix, "map_matrix")) return NULL;
  if ((pyobj_fillval != NULL) && !convert_to_CvScalar(pyobj_fillval, &fillval, "fillval")) return NULL;
  ERRWRAP(cvWarpAffine(src, dst, map_matrix, flags, fillval));
  Py_RETURN_NONE;
}

static PyObject *pycvWarpPerspective(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src;
  PyObject *pyobj_src = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvMat* map_matrix;
  PyObject *pyobj_map_matrix = NULL;
  int flags = CV_INTER_LINEAR+CV_WARP_FILL_OUTLIERS;
  CvScalar fillval = cvScalarAll(0);
  PyObject *pyobj_fillval = NULL;

  const char *keywords[] = { "src", "dst", "map_matrix", "flags", "fillval", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|iO", (char**)keywords, &pyobj_src, &pyobj_dst, &pyobj_map_matrix, &flags, &pyobj_fillval))
    return NULL;
  if (!convert_to_CvArr(pyobj_src, &src, "src")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if (!convert_to_CvMat(pyobj_map_matrix, &map_matrix, "map_matrix")) return NULL;
  if ((pyobj_fillval != NULL) && !convert_to_CvScalar(pyobj_fillval, &fillval, "fillval")) return NULL;
  ERRWRAP(cvWarpPerspective(src, dst, map_matrix, flags, fillval));
  Py_RETURN_NONE;
}

static PyObject *pycvWatershed(PyObject *self, PyObject *args)
{
  CvArr* image;
  PyObject *pyobj_image = NULL;
  CvArr* markers;
  PyObject *pyobj_markers = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_image, &pyobj_markers))
    return NULL;
  if (!convert_to_CvArr(pyobj_image, &image, "image")) return NULL;
  if (!convert_to_CvArr(pyobj_markers, &markers, "markers")) return NULL;
  ERRWRAP(cvWatershed(image, markers));
  Py_RETURN_NONE;
}

static PyObject *pycvWriteFrame(PyObject *self, PyObject *args)
{
  CvVideoWriter* writer;
  PyObject *pyobj_writer = NULL;
  IplImage* image;
  PyObject *pyobj_image = NULL;

  if (!PyArg_ParseTuple(args, "OO", &pyobj_writer, &pyobj_image))
    return NULL;
  if (!convert_to_CvVideoWriterPTR(pyobj_writer, &writer, "writer")) return NULL;
  if (!convert_to_IplImage(pyobj_image, &image, "image")) return NULL;
  int r;
  ERRWRAP(r = cvWriteFrame(writer, image));
  return FROM_int(r);
}

static PyObject *pycvXor(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvArr* src2;
  PyObject *pyobj_src2 = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "src1", "src2", "dst", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|O", (char**)keywords, &pyobj_src1, &pyobj_src2, &pyobj_dst, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvArr(pyobj_src2, &src2, "src2")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvXor(src1, src2, dst, mask));
  Py_RETURN_NONE;
}

static PyObject *pycvXorS(PyObject *self, PyObject *args, PyObject *kw)
{
  CvArr* src1;
  PyObject *pyobj_src1 = NULL;
  CvScalar value;
  PyObject *pyobj_value = NULL;
  CvArr* dst;
  PyObject *pyobj_dst = NULL;
  CvArr* mask = NULL;
  PyObject *pyobj_mask = NULL;

  const char *keywords[] = { "src1", "value", "dst", "mask", NULL };
  if (!PyArg_ParseTupleAndKeywords(args, kw, "OOO|O", (char**)keywords, &pyobj_src1, &pyobj_value, &pyobj_dst, &pyobj_mask))
    return NULL;
  if (!convert_to_CvArr(pyobj_src1, &src1, "src1")) return NULL;
  if (!convert_to_CvScalar(pyobj_value, &value, "value")) return NULL;
  if (!convert_to_CvArr(pyobj_dst, &dst, "dst")) return NULL;
  if ((pyobj_mask != NULL) && !convert_to_CvArr(pyobj_mask, &mask, "mask")) return NULL;
  ERRWRAP(cvXorS(src1, value, dst, mask));
  Py_RETURN_NONE;
}

static PyObject *pycvZero(PyObject *self, PyObject *args)
{
  CvArr* arr;
  PyObject *pyobj_arr = NULL;

  if (!PyArg_ParseTuple(args, "O", &pyobj_arr))
    return NULL;
  if (!convert_to_CvArr(pyobj_arr, &arr, "arr")) return NULL;
  ERRWRAP(cvZero(arr));
  Py_RETURN_NONE;
}

static PyObject *pycvmGet(PyObject *self, PyObject *args)
{
  CvMat* mat;
  PyObject *pyobj_mat = NULL;
  int row;
  int col;

  if (!PyArg_ParseTuple(args, "Oii", &pyobj_mat, &row, &col))
    return NULL;
  if (!convert_to_CvMat(pyobj_mat, &mat, "mat")) return NULL;
  double r;
  ERRWRAP(r = cvmGet(mat, row, col));
  return FROM_double(r);
}

static PyObject *pycvmSet(PyObject *self, PyObject *args)
{
  CvMat* mat;
  PyObject *pyobj_mat = NULL;
  int row;
  int col;
  double value;

  if (!PyArg_ParseTuple(args, "Oiid", &pyobj_mat, &row, &col, &value))
    return NULL;
  if (!convert_to_CvMat(pyobj_mat, &mat, "mat")) return NULL;
  ERRWRAP(cvmSet(mat, row, col, value));
  Py_RETURN_NONE;
}
